@@ -1,7 +1,7 @@
 /* 
  * Per client (conquest) info
  *
- * $Id: clientlb.h,v 1.3 2003/12/07 09:35:32 jon Exp $
+ * $Id: clientlb.h,v 1.4 2004/05/08 21:01:41 jon Exp $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -13,17 +13,7 @@
 #include "datatypes.h"
 #include "protocol.h"
 
-#ifdef CLIENT_NOEXTERN
-# define EXTERNAL extern
-#else
-# define EXTERNAL
-#endif
-
-void clntPseudo( int unum, int snum );
-void clntDoWar( int snum );
 void clntStoreMessage(spMessage_t *msg);
-
-void clntSendMsg( int from, int terse, int remote );
 void clntDisplayFeedback(char *msg);
 char *clntServerFlagsStr(Unsgn32 flags);
 
