@@ -4,7 +4,7 @@
  *
  * conf.c - handle configuration issues, both personal and system wide.
  *
- * $Id: conf.c,v 1.16 2003/12/21 22:41:01 jon Exp $
+ * $Id: conf.c,v 1.19 2004/11/24 01:31:12 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -20,6 +20,7 @@
 #include "global.h"
 #include "conqcom.h"
 #include "color.h"
+#include "ui.h"
 #include "datatypes.h"
 #include "conqnet.h"
 
@@ -72,6 +73,8 @@ int GetSysConf(int checkonly)
 	  CONF_SERVER_NAME_SZ);
   strncpy(SysConf.ServerMotd, "Keep your shields up in battle.",
 	  CONF_SERVER_MOTD_SZ);
+  strncpy(SysConf.ServerContact, "root@localhost",
+	  META_GEN_STRSIZE);
 
 				/* start building the filename */
   snprintf(conf_name, sizeof(conf_name)-1, "%s/%s", CONQETC, SYSCONFIG_FILE);
@@ -288,6 +291,8 @@ int GetConf(int usernum)
   UserConf.DoLRTorpScan = TRUE;
   UserConf.DoLocalLRScan = TRUE;
   UserConf.DoETAStats = TRUE;
+  UserConf.EnemyShipBox = TRUE;
+  UserConf.doVBG = TRUE;
 
   for (i=0; i<MAX_MACROS; i++)
     {
@@ -498,19 +503,12 @@ int GetConf(int usernum)
 }
 
 /* SaveUserConfig(int unum) - do what the name implies ;-) */
-int SaveUserConfig(int unum)
+int SaveUserConfig(void)
 {
   char conf_name[MID_BUFFER_SIZE];
   char *homevar;
   char home[HOME_BUFSZ];
 
-  /* telnet shell clients can't save their configs :( */
-  if (telnetClient)
-    {
-      InitColors();
-      return TRUE;
-    }
-
 				/* start building the filename */
   if ((homevar = getenv("HOME")) == NULL)
     {
@@ -529,9 +527,6 @@ int SaveUserConfig(int unum)
   clog("SaveUserConfig(): saving user config: conf_name = '%s'", conf_name);
 #endif
 
-				/* re-init in case it was changed */
-  InitColors();
-
   return(MakeConf(conf_name));
 }
 
