@@ -2,7 +2,7 @@
  *
  * conf.h - header for conf.c
  *
- * $Id: conf.h,v 1.23 2003/12/13 20:52:48 jon Exp $
+ * $Id: conf.h,v 1.26 2004/11/24 01:31:12 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -19,7 +19,6 @@
 #define CONF_H
 
 #include "datatypes.h"
-
 #ifdef CONF_NOEXTERN
 # define CEXTERN
 #else
@@ -42,6 +41,8 @@
 #define CONF_SERVER_NAME_SZ   70
 #define CONF_SERVER_MOTD_SZ   70
 
+#include "meta.h"
+
 struct Conf 
 {
   int Found;
@@ -101,10 +102,14 @@ typedef struct _userConf {
 
 				/* can see friendly torps on LR scan? */
   int DoLRTorpScan;
-				/* (M)ap is actually LongeRange scan? */
+                              /* (M)ap is actually LongeRange scan? */
   int DoLocalLRScan;
-				/* (I)nfo cmds return ETA data? */
+                                /* (I)nfo cmds return ETA data? */
   int DoETAStats;
+     /* for the GL client only - draws a red box around enemy ships */
+  int EnemyShipBox;
+
+  int doVBG;                    /* draw the background in the viewer? */
 
   char MacrosF[MAX_MACROS][MAX_MACRO_LEN];
 
@@ -137,6 +142,8 @@ typedef struct _sysConf {
   char ServerName[CONF_SERVER_NAME_SZ];
   /* server motd */
   char ServerMotd[CONF_SERVER_MOTD_SZ];
+  /* server owner contact info */
+  char ServerContact[META_GEN_STRSIZE];
 
 } SysConf_t;
 
@@ -148,7 +155,7 @@ typedef struct _sysConf {
 CEXTERN char ConfigVersion[];
 
 #else
-char ConfigVersion[] = "$Revision: 1.23 $";
+char ConfigVersion[] = "$Revision: 1.26 $";
 #endif /* CONF_NOEXTERN */
 
 /* Config's */
@@ -160,7 +167,7 @@ void confSetTelnetClientMode(int telnetc);
 CEXTERN int GetSysConf(int checkonly);
 CEXTERN int GetConf(int usernum);
 CEXTERN int MakeSysConf(void);
-CEXTERN int SaveUserConfig(int unum);
+CEXTERN int SaveUserConfig(void);
 CEXTERN int SaveSysConfig(void);
 CEXTERN char *Str2Macro(char *str);
 CEXTERN char *Macro2Str(char *str);
@@ -356,6 +363,19 @@ struct Conf SysConfData[] =
       "#  Default: Keep your shields up in battle.",
       NULL
     }
+  },
+  {
+    FALSE,
+    CTYPE_STRING,
+    "server_contact=",
+    SysConf.ServerContact,
+    0, META_GEN_STRSIZE,	/* mix/max */
+    "Server Contact Info",
+    {
+      "# Email address or URL to use to contact the server owner.",
+      "#  Default: root@localhost",
+      NULL
+    }
   }
 };
 #endif /* CONF_NOEXTERN */
@@ -639,6 +659,35 @@ struct Conf ConfData[] =
       NULL
     }
   },
+  {
+    TRUE,
+    CTYPE_BOOL,
+    "do_enemyshipbox=",
+    &UserConf.EnemyShipBox,
+    0, 0,			/* mix/max */
+    "Draw a red box around enemy ships (GL client only)",
+    {
+      "# define this as 'true' if you want a red box drawn around",
+      "#  enemy ships on the viewer.  Valid for GL client only.",
+      "#  Default: true",
+      NULL
+    }
+  },
+  {
+    TRUE,
+    CTYPE_BOOL,
+    "do_draw_viewerbg=",
+    &UserConf.doVBG,
+    0, 0,			/* mix/max */
+    "Draw the background image in the viewer(GL client only)",
+    {
+      "# define this as 'true' if you want to see the rather attractive",
+      "#  background image displayed in the viewer.  ",
+      "#  Valid for GL client only.",
+      "#  Default: true",
+      NULL
+    }
+  },
   {				/* Macros are special - these should be last */
     FALSE,
     CTYPE_MACRO,
