@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conqcm.c,v 1.13 2003/11/02 20:53:00 jon Exp $
+ * $Id: conqcm.c,v 1.15 2004/12/12 05:32:11 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -25,13 +25,14 @@
 /**********************************************************************/
 
 #include "global.h"
-
 #include "conqdef.h"
+#include "conqlb.h"
 
 #define NOCOMEXTERN
 #include "conqcom.h"		/* common block vars defined here */
 #include "context.h"		/* some extra stuff */
 #include "user.h"
+#include "sem.h"
 
 static char *cBasePtr = NULL;	/* common block ptr */
 static int coff = 0;		/* offset into common block */
@@ -149,7 +150,7 @@ int check_cblock(char *fname, int fmode, int sizeofcb)
 	    {			/* Create it */
 	      printf("Initializing common block: %s\n", fname);
 	      cBasePtr = (char *) mymalloc(sizeofcb); /* this exits if malloc fails */
-	      cdfill('\0', cBasePtr, sizeofcb);
+              memset(cBasePtr, 0, sizeofcb);
 
 	      write(ffd, cBasePtr, sizeofcb);
 	      close(ffd);
@@ -301,10 +302,27 @@ void fake_common(void)
   fakeCommon = TRUE;
 
   /* this will exit if it fails */
-  cBasePtr = mymalloc(SIZEOF_COMMONBLOCK);
+  if (!cBasePtr)
+    cBasePtr = mymalloc(SIZEOF_COMMONBLOCK);
 
   map_vars();
 
   zero_common();
   return;
 }
+
+/* short cut */
+void map_lcommon(void)
+{
+  /* a parallel universe, it is */
+  fake_common();
+  clbInitEverything();
+  clbInitMsgs();
+  *CBlockRevision = COMMONSTAMP;
+  ConqInfo->closed = FALSE;
+  Driver->drivstat = DRS_OFF;
+  Driver->drivpid = 0;
+  Driver->drivowner[0] = EOS;
+  
+  return;
+}
