@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conqoper.c,v 1.21 2004/01/08 06:12:28 jon Exp $
+ * $Id: conqoper.c,v 1.26 2004/12/12 05:32:11 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -29,13 +29,22 @@
 #include "conf.h"
 #include "conqdef.h"
 #include "conqcom.h"
+#include "conqlb.h"
 #include "context.h"
 #include "global.h"
+#include "sem.h"
 #include "color.h"
+#include "ui.h"
+#include "options.h"
+#include "cd2lb.h"
+#include "iolb.h"
+#include "cumisc.h"
+#include "cuclient.h"
 #include "record.h"
-#include "display.h"
 #include "clientlb.h"
 #include "clntauth.h"
+#include "cuclient.h"
+#include "display.h"
 
 static char cbuf[MID_BUFFER_SIZE]; /* general purpose buffer */
 
@@ -54,6 +63,33 @@ void EnableConqoperSignalHandler(void);
 void operStopTimer(void);
 void operSetTimer(void);
 
+void bigbang(void);
+void debugdisplay( int snum );
+void debugplan(void);
+int opPlanetMatch( char str[], int *pnum );
+void kiss(int snum, int prompt_flg);
+void opback( int lastrev, int *savelin );
+void operate(void);
+void opinfo( int snum );
+void opinit(void);
+void opPlanetList(void);
+void opresign(void);
+void oprobot(void);
+void opstats(void);
+void opTeamList(void);
+void opuadd(void);
+void oppedit(void);
+void opuedit(void);
+void watch(void);
+int prompt_ship(char buf[], int *snum, int *normal);
+void dowatchhelp(void);
+void setdheader(int show_header);
+void toggle_line(int snum, int old_snum);
+char *build_toggle_str(char snum_str[], int snum);
+void menu_item( char *option, char *msg_line, int lin, int col );
+int DoInit(char InitChar, int cmdline);
+
+
 /*  conqoper - main program */
 int main(int argc, char *argv[])
 {
@@ -68,7 +104,7 @@ int main(int argc, char *argv[])
 
   OptionAction = OP_NONE;
 
-  strncpy(operName, glname(), MAXUSERNAME);
+  strncpy(operName, clbGetUserLogname(), MAXUSERNAME);
   operName[MAXUSERNAME - 1] = 0;
 
   if ( ! isagod(-1) )
@@ -118,15 +154,9 @@ int main(int argc, char *argv[])
 	break;
       }
 
-  if ((ConquestUID = GetUID(ROOT_USER)) == ERR)
+  if ((ConquestGID = getConquestGID()) == ERR)
     {
-      fprintf(stderr, "conqoper: GetUID() failed\n");
-      exit(1);
-    }
-  
-  if ((ConquestGID = GetConquestGID()) == ERR)
-    {
-      fprintf(stderr, "conqoper: GetConquestGID() failed\n");
+      fprintf(stderr, "conqoper: getConquestGID() failed\n");
       exit(1);
     }
   
@@ -140,9 +170,9 @@ int main(int argc, char *argv[])
 	  exit(1);
 	}
 
-      if (GetSem() == ERR)
+      if (semInit() == ERR)
 	{
-	  fprintf(stderr, "GetSem() failed to get semaphores. exiting.\n");
+	  fprintf(stderr, "semInit() failed to get semaphores. exiting.\n");
 	  exit(1);
 	}
 
@@ -224,9 +254,9 @@ int main(int argc, char *argv[])
       exit(1);
     }
   
-  if (GetSem() == ERR)
+  if (semInit() == ERR)
     {
-      fprintf(stderr, "GetSem() failed to get semaphores. exiting.\n");
+      fprintf(stderr, "semInit() failed to get semaphores. exiting.\n");
       exit(1);
     }
   
@@ -248,8 +278,8 @@ int main(int argc, char *argv[])
 #endif
   
   
-  map_common();			/* Map the conquest universe common block */
   rndini( 0, 0 );		/* initialize random numbers */
+  map_common();			/* Map the conquest universe common block */
   cdinit();			/* initialize display environment */
   
   Context.unum = MSG_GOD;	/* stow user number */
@@ -267,7 +297,7 @@ int main(int argc, char *argv[])
   sprintf(msgbuf, "OPER: User %s has entered conqoper.",
           operName);
   clog(msgbuf);			/* log it too... */
-  stormsg( MSG_COMP, MSG_GOD, msgbuf );
+  clbStoreMsg( MSG_COMP, MSG_GOD, msgbuf );
 
   operate();
   
@@ -292,7 +322,7 @@ void bigbang(void)
     if ( Ships[snum].status == SS_LIVE )
       {
 	for ( i = 0; i < MAXTORPS; i = i + 1 )
-	  if ( ! launch( snum, dir, 1, LAUNCH_NORMAL ) )
+	  if ( ! clbLaunch( snum, dir, 1, LAUNCH_NORMAL ) )
 	    break;
 	  else
 	    {
@@ -645,7 +675,7 @@ void debugplan(void)
 
       for ( i = 1; i <= NUMPLANETS; i = i + 1 )
 	sv[i] = i;
-      sortplanets( sv );
+      clbSortPlanets( sv );
     }
   
   strcpy( hd3, hd2 );
@@ -664,7 +694,7 @@ void debugplan(void)
   Done = FALSE;
   do
     {
-      cdclra(0, 0, MSG_LIN1 + 2, cdcols() - 1);
+      cdclra(0, 0, MSG_LIN1 + 2, Context.maxcol - 1);
       PlanetIdx = 0;
       
       lin = 1;
@@ -715,7 +745,7 @@ void debugplan(void)
 		case PLANET_CLASSA:
 		case PLANET_CLASSO:
 		case PLANET_CLASSZ:
-		  outattr = A_BOLD;
+		  outattr = CQC_A_BOLD;
 		  break;
 		case PLANET_GHOST:
 		  outattr = NoColor;
@@ -746,13 +776,13 @@ void debugplan(void)
 		  lin = olin;
 		  col = 44;
 		}
-	      attrset(0);
+	      uiPutColor(0);
 	    } /* while */
 	  
 	  if ((PlanetOffset + PlanetIdx) > NUMPLANETS)
-	    putpmt( MTXT_DONE, MSG_LIN2 ); /* last page? */
+	    mcuPutPrompt( MTXT_DONE, MSG_LIN2 ); /* last page? */
 	  else
-	    putpmt( MTXT_MORE, MSG_LIN2 );
+	    mcuPutPrompt( MTXT_MORE, MSG_LIN2 );
 
           cdrefresh();
 	  
@@ -790,8 +820,8 @@ void debugplan(void)
 /*    int gplanmatch, pnum */
 /*    char str() */
 /*    int status */
-/*    status = gplanmatch( str, pnum ) */
-int gplanmatch( char str[], int *pnum )
+/*    status = opPlanetMatch( str, pnum ) */
+int opPlanetMatch( char str[], int *pnum )
 {
   int i;
   
@@ -804,7 +834,7 @@ int gplanmatch( char str[], int *pnum )
 	return ( FALSE );
     }
   else
-    return ( planmatch( str, pnum, TRUE ) );
+    return ( clbPlanetMatch( str, pnum, TRUE ) );
   
   return ( TRUE );
   
@@ -863,7 +893,7 @@ void kiss(int snum, int prompt_flg)
       cdclrl( MSG_LIN1, 1 ); 
       sprintf(mbuf,"%s", kill_driver_str);
       cdputs( mbuf, MSG_LIN1, 1 );
-      if ( confirm() )
+      if ( mcuConfirm() )
 	if ( Driver->drivstat == DRS_RUNNING )
 	  Driver->drivstat = DRS_KAMIKAZE;
       cdclrl( MSG_LIN1, 2 );
@@ -895,9 +925,9 @@ void kiss(int snum, int prompt_flg)
 	sprintf(mbuf, kill_ship_str1,
 		Teams[Ships[snum].team].teamchar, snum, Ships[snum].alias);
 	cdputs( mbuf, MSG_LIN1, 1 );
-	if ( confirm() )
+	if ( mcuConfirm() )
 	  {
-	    killship( snum, KB_GOD );
+	    clbKillShip( snum, KB_GOD );
 	    cdclrl( MSG_LIN2, 1 );
 	    clog("OPER: %s killed ship %d",
 		 operName, snum);
@@ -922,11 +952,11 @@ void kiss(int snum, int prompt_flg)
 		    snum, 
 		    Ships[snum].alias);
 	    cdputs( buf, MSG_LIN1, 1 );
-	    if ( confirm() )
+	    if ( mcuConfirm() )
 	      {
 		clog("OPER: %s killed ship %d",
 		     operName, snum);
-		killship( snum, KB_GOD );
+		clbKillShip( snum, KB_GOD );
 	      }
 	  }
       if ( didany )
@@ -938,7 +968,7 @@ void kiss(int snum, int prompt_flg)
     }
   
   /* Kill a user? */
-  if ( ! gunum( &unum, buf, -1 ) )
+  if ( ! clbGetUserNum( &unum, buf, -1 ) )
     {
       cdputs( no_user_str, MSG_LIN2, 1 );
       cdmove( 0, 0 );
@@ -959,9 +989,9 @@ void kiss(int snum, int prompt_flg)
 		  Ships[snum].alias, 
 		  buf);
 	  cdputs( mbuf, MSG_LIN1, 1 );
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 		  {
-	    killship( snum, KB_GOD );
+	    clbKillShip( snum, KB_GOD );
 	    cdclrl( MSG_LIN2, 1 );
 	    clog("OPER: %s killed ship %d",
 		 operName, snum);
@@ -1010,20 +1040,20 @@ void opback( int lastrev, int *savelin )
   lin = 1;
   if ( lastrev == COMMONSTAMP ) 
     {
-      attrset(NoColor|A_BOLD);
+      uiPutColor(NoColor|CQC_A_BOLD);
       cdputc( "CONQUEST OPERATOR PROGRAM", lin );
-      attrset(YellowLevelColor);
+      uiPutColor(YellowLevelColor);
       sprintf( cbuf, "%s (%s)",
 	       ConquestVersion, ConquestDate);
       cdputc( cbuf, lin+1 );
     }
   else
     {
-      attrset(RedLevelColor);
+      uiPutColor(RedLevelColor);
       sprintf( cbuf, "CONQUEST COMMON BLOCK MISMATCH %d != %d",
 	       lastrev, COMMONSTAMP );
       cdputc( cbuf, lin );
-      attrset(0);
+      uiPutColor(0);
     }
   
   EnableConqoperSignalHandler(); /* enable trapping of interesting signals */
@@ -1184,13 +1214,13 @@ void operate(void)
 		  xbuf,LabelColor,", eater ",InfoColor,buf);
 	  
 	  /* Line 2. */
-	  strcpy(buf, GetSemVal(0));
+	  strcpy(buf, semGetStatusStr());
 
 	  lin++;
 	  cdclrl( lin, 1 );
-	  attrset(SpecialColor);
+	  uiPutColor(SpecialColor);
 	  cdputc( buf, lin );
-	  attrset(0);
+	  uiPutColor(0);
       
 
 	  /* Display a new message, if any. */
@@ -1198,7 +1228,7 @@ void operate(void)
 	  if ( dgrand( msgrand, &now ) >= NEWMSG_GRAND )
 	    if ( getamsg( MSG_GOD, &ConqInfo->glastmsg ) )
 	      {
-		readmsg( MSG_GOD, ConqInfo->glastmsg, RMsg_Line );
+		mcuReadMsg( MSG_GOD, ConqInfo->glastmsg, RMsg_Line );
 		
 #if defined(OPER_MSG_BEEP)
 		if (Msgs[ConqInfo->glastmsg].msgfrom != MSG_GOD)
@@ -1236,7 +1266,7 @@ void operate(void)
 	  redraw = TRUE;
 	  break;
 	case 'b':
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 	    bigbang();
 	  break;
 	case 'd':
@@ -1248,7 +1278,7 @@ void operate(void)
 	    }
 	  else
 	    {
-	      doomsday();
+	      clbDoomsday();
 	      clog("OPER: %s has ACTIVATED the Doomsday machine",
 		   operName);
 	    }
@@ -1271,7 +1301,7 @@ void operate(void)
 	      clog("OPER: %s has enabled the game",
 		   operName);
 	    }
-	  else if ( confirm() )
+	  else if ( mcuConfirm() )
 	    {
 	      ConqInfo->closed = TRUE;
 	      clog("OPER: %s has disabled the game",
@@ -1285,7 +1315,7 @@ void operate(void)
 	    Driver->drivstat = DRS_HOLDING;
 	  break;
 	case 'H':
-	  histlist( TRUE );
+	  mcuHistList( TRUE );
 	  redraw = TRUE;
 	  break;
 	case 'i':
@@ -1299,10 +1329,10 @@ void operate(void)
 	  kiss(0,TRUE);
 	  break;
 	case 'L':
-	  review( MSG_GOD, ConqInfo->glastmsg );
+	  mcuReviewMsgs( MSG_GOD, ConqInfo->glastmsg );
 	  break;
 	case 'm':
-	  clntSendMsg( MSG_GOD, TRUE, FALSE );
+	  cucSendMsg( MSG_GOD, TRUE, FALSE );
 	  break;
 	case 'O':
 	  SysOptsMenu();
@@ -1328,15 +1358,15 @@ void operate(void)
 	  redraw = TRUE;
 	  break;
 	case 'S':
-	  userstats( TRUE , 0 ); /* we're always neutral ;-) - dwp */
+	  mcuUserStats( TRUE , 0 ); /* we're always neutral ;-) - dwp */
 	  redraw = TRUE;
 	  break;
 	case 'T':
-	  opteamlist();
+	  opTeamList();
 	  redraw = TRUE;
 	  break;
 	case 'U':
-	  userlist( TRUE, 0 );
+	  mcuUserList( TRUE, 0 );
 	  redraw = TRUE;
 	  break;
 	case 'w':
@@ -1345,15 +1375,15 @@ void operate(void)
 	  redraw = TRUE;
 	  break;
 	case '/':
-	  playlist( TRUE, FALSE, 0 );
+	  mcuPlayList( TRUE, FALSE, 0 );
 	  redraw = TRUE;
 	  break;
 	case '\\':
-	  playlist( TRUE, TRUE, 0 );
+	  mcuPlayList( TRUE, TRUE, 0 );
 	  redraw = TRUE;
 	  break;
 	case '?':
-	  opplanlist();
+	  opPlanetList();
 	  redraw = TRUE;
 	  break;
 	case '$':
@@ -1413,29 +1443,29 @@ void opinfo( int snum )
     {
       i = 0;
       safectoi( &j, &cbuf[1], i );		/* ignore status */
-      infoship( j, snum );
+      mcuInfoShip( j, snum );
     }
   else if ( alldig( cbuf ) == TRUE )
     {
       i = 0;
       safectoi( &j, cbuf, i );		/* ignore status */
-      infoship( j, snum );
+      mcuInfoShip( j, snum );
     }
-  else if ( gplanmatch( cbuf, &j ) )
-    infoplanet( "", j, snum );
+  else if ( opPlanetMatch( cbuf, &j ) )
+    mcuInfoPlanet( "", j, snum );
   else if ( stmatch( cbuf, "time", FALSE ) )
     {
       getnow( now, 0 );
       c_strcpy( "It's ", cbuf );
       appnumtim( now, cbuf );
       appchr( '.', cbuf );
-      c_putmsg( cbuf, MSG_LIN1 );
+      mcuPutMsg( cbuf, MSG_LIN1 );
       cdmove( MSG_LIN1, 1 );
     }
   else
     {
       cdmove( MSG_LIN2, 1 );
-      c_putmsg( huh, MSG_LIN2 );
+      mcuPutMsg( huh, MSG_LIN2 );
     }
   
   return;
@@ -1459,41 +1489,41 @@ void opinit(void)
   
   lin = 2;
   icol = 11;
-  attrset(LabelColor);
+  uiPutColor(LabelColor);
   cdputc( "Conquest Initialization", lin );
   
   lin+=3;
   col = icol - 2;
   c_strcpy( "(r)obots", buf );
   i = strlen( buf );
-  attrset(InfoColor);
+  uiPutColor(InfoColor);
   cdputs( buf, lin, col+1 );
-  attrset(A_BOLD);
+  uiPutColor(CQC_A_BOLD);
   cdbox( lin-1, col, lin+1, col+i+1 );
   col = col + i + 4;
-  attrset(LabelColor);
+  uiPutColor(LabelColor);
   cdputs( "<-", lin, col );
   col = col + 4;
   c_strcpy( "(e)verything", buf );
   i = strlen( buf );
-  attrset(InfoColor);
+  uiPutColor(InfoColor);
   cdputs( buf, lin, col+1 );
-  attrset(A_BOLD);
+  uiPutColor(CQC_A_BOLD);
   cdbox( lin-1, col, lin+1, col+i+1 );
   col = col + i + 4;
-  attrset(LabelColor);
+  uiPutColor(LabelColor);
   cdputs( ".", lin, col );
   col = col + 4;
   c_strcpy( "(z)ero everything", buf );
   i = strlen( buf );
-  attrset(InfoColor);
+  uiPutColor(InfoColor);
   cdputs( buf, lin, col+1 );
-  attrset(A_BOLD);
+  uiPutColor(CQC_A_BOLD);
   cdbox( lin-1, col, lin+1, col+i+1 );
   
   col = icol + 20;
   lin+=3;
-  attrset(LabelColor);
+  uiPutColor(LabelColor);
   cdput( '|', lin, col );
   lin++;
   cdput( 'v', lin, col );
@@ -1502,44 +1532,44 @@ void opinit(void)
   col = icol;
   c_strcpy( "(s)hips", buf );
   i = strlen( buf );
-  attrset(InfoColor);
+  uiPutColor(InfoColor);
   cdputs( buf, lin, col+1 );
-  attrset(A_BOLD);
+  uiPutColor(CQC_A_BOLD);
   cdbox( lin-1, col, lin+1, col+i+1 );
   col = col + i + 4;
-  attrset(LabelColor);
+  uiPutColor(LabelColor);
   cdputs( "<-", lin, col );
   col = col + 4;
   c_strcpy( "(u)niverse", buf );
   i = strlen( buf );
-  attrset(InfoColor);
+  uiPutColor(InfoColor);
   cdputs( buf, lin, col+1 );
-  attrset(A_BOLD);
+  uiPutColor(CQC_A_BOLD);
   cdbox( lin-1, col, lin+1, col+i+1 );
   col = col + i + 4;
-  attrset(LabelColor);
+  uiPutColor(LabelColor);
   cdputs( ".", lin, col );
   col = col + 4;
   c_strcpy( "(g)ame", buf );
   i = strlen( buf );
-  attrset(InfoColor);
+  uiPutColor(InfoColor);
   cdputs( buf, lin, col+1 );
-  attrset(A_BOLD);
+  uiPutColor(CQC_A_BOLD);
   cdbox( lin-1, col, lin+1, col+i+1 );
   col = col + i + 4;
-  attrset(LabelColor);
+  uiPutColor(LabelColor);
   cdputs( ".", lin, col );
   col = col + 4;
   c_strcpy( "(p)lanets", buf );
   i = strlen( buf );
-  attrset(InfoColor);
+  uiPutColor(InfoColor);
   cdputs( buf, lin, col+1 );
-  attrset(A_BOLD);
+  uiPutColor(CQC_A_BOLD);
   cdbox( lin-1, col, lin+1, col+i+1 );
   
   col = icol + 20;
   lin+=3;
-  attrset(LabelColor);
+  uiPutColor(LabelColor);
   cdput( '|', lin, col );
   lin++;
   cdput( 'v', lin, col );
@@ -1548,16 +1578,16 @@ void opinit(void)
   col = icol + 15;
   c_strcpy( "(m)essages", buf );
   i = strlen( buf );
-  attrset(InfoColor);
+  uiPutColor(InfoColor);
   cdputs( buf, lin, col+1 );
-  attrset(A_BOLD);
+  uiPutColor(CQC_A_BOLD);
   cdbox( lin-1, col, lin+1, col+i+1 );
   col = col + i + 8;
   c_strcpy( "(l)ockwords", buf );
   i = strlen( buf );
-  attrset(InfoColor);
+  uiPutColor(InfoColor);
   cdputs( buf, lin, col+1 );
-  attrset(A_BOLD);
+  uiPutColor(CQC_A_BOLD);
   cdbox( lin-1, col, lin+1, col+i+1 );
   
   while (TRUE)  /*repeat */
@@ -1565,12 +1595,12 @@ void opinit(void)
       lin = MSG_LIN1;
       col = 30;
       cdclrl( lin, 1 );
-      attrset(InfoColor);
+      uiPutColor(InfoColor);
       buf[0] = EOS;
       ch = (char)cdgetx( pmt, lin, col, TERMS, buf, MSGMAXLINE, TRUE );
       cdclrl( lin, 1 );
       cdputs( pmt, lin, col );
-  	  attrset(0);
+  	  uiPutColor(0);
       col = col + strlen( pmt );
       if ( ch == TERM_ABORT || buf[0] == EOS )
 	break;
@@ -1578,61 +1608,61 @@ void opinit(void)
 	{
 	case 'e':
 	  cdputs( "everything", lin, col );
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 	    {
 	      DoInit('e', FALSE);
 	    }
 	  break;
 	case 'z':
 	  cdputs( "zero everything", lin, col );
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 	    DoInit('z', FALSE);
 	  break;
 	case 'u':
 	  cdputs( "universe", lin, col );
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 	    {
 	      DoInit('u', FALSE);
 	    }
 	  break;
 	case 'g':
 	  cdputs( "game", lin, col );
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 	    {
 	      DoInit('g', FALSE);
 	    }
 	  break;
 	case 'p':
 	  cdputs( "planets", lin, col );
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 	    {
 	      DoInit('p', FALSE);
 	    }
 	  break;
 	case 's':
 	  cdputs( "ships", lin, col );
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 	    {
 	      DoInit('s', FALSE);
 	    }
 	  break;
 	case 'm':
 	  cdputs( "messages", lin, col );
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 	    {
 	      DoInit('m', FALSE);
 	    }
 	  break;
 	case 'l':
 	  cdputs( "lockwords", lin, col );
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 	    {
 	      DoInit('l', FALSE);
 	    }
 	  break;
 	case 'r':
 	  cdputs( "robots", lin, col );
-	  if ( confirm() )
+	  if ( mcuConfirm() )
 	    {
 	      DoInit('r', FALSE);
 	    }
@@ -1698,31 +1728,31 @@ void oppedit(void)
 		Planets[pnum].type == PLANET_CLASSO ||
 		Planets[pnum].type == PLANET_CLASSZ ||
 		Planets[pnum].type == PLANET_GHOST )   /* white as a ghost ;-) */
-	attrib = A_BOLD;
+	attrib = CQC_A_BOLD;
       else 
 	attrib = SpecialColor;
       
 				/* if we're doing a sun, use yellow
 				   else use attrib set above */
       if (Planets[pnum].type == PLANET_SUN)
-	attrset(YellowLevelColor);
+	uiPutColor(YellowLevelColor);
       else
-	attrset(attrib);
-      puthing(Planets[pnum].type, i, j );
-      attrset(0);
+	uiPutColor(attrib);
+      mcuPutThing(Planets[pnum].type, i, j );
+      uiPutColor(0);
 
 	  /* suns have red cores, others are cyan. */
       if (Planets[pnum].type == PLANET_SUN)
-	attrset(RedLevelColor);
+	uiPutColor(RedLevelColor);
       else
-	attrset(InfoColor);
+	uiPutColor(InfoColor);
       cdput( ConqInfo->chrplanets[Planets[pnum].type], i, j + 1);
-      attrset(0);
+      uiPutColor(0);
 
       sprintf(buf, "%s\n", Planets[pnum].name);
-      attrset(attrib);
+      uiPutColor(attrib);
       cdputs( buf, i + 1, j + 2 ); /* -[] */
-      attrset(0);
+      uiPutColor(0);
       
       /* Display info about the planet. */
       lin = 4;
@@ -1822,7 +1852,7 @@ void oppedit(void)
       cprintf(lin,col,ALIGN_NONE,sfmt, "<>", 
 		" decrement/increment planet number\n");
       
-      cdclra(MSG_LIN1, 0, MSG_LIN1 + 2, cdcols() - 1);
+      cdclra(MSG_LIN1, 0, MSG_LIN1 + 2, Context.maxcol - 1);
       
       cdmove( 0, 0 );
       cdrefresh();
@@ -1833,7 +1863,7 @@ void oppedit(void)
 	{
 	case 'a':
 	  /* Angle. */
-	  ch = getcx( "New angle? ", MSG_LIN1, 0,
+	  ch = mcuGetCX( "New angle? ", MSG_LIN1, 0,
 		     TERMS, buf, MSGMAXLINE );
 	  if ( ch == TERM_ABORT || buf[0] == EOS )
 	    continue;	/* next */
@@ -1849,7 +1879,7 @@ void oppedit(void)
 	  break;
 	case 'A':
 	  /* Armies. */
-	  ch = getcx( "New number of armies? ",
+	  ch = mcuGetCX( "New number of armies? ",
 		     MSG_LIN1, 0, TERMS, buf, MSGMAXLINE );
 	  if ( ch == TERM_ABORT || buf[0] == EOS )
 	    continue;
@@ -1861,25 +1891,25 @@ void oppedit(void)
 	  break;
 	case 'n':
 	  /* New planet name. */
-	  ch = getcx( "New name for this planet? ",
+	  ch = mcuGetCX( "New name for this planet? ",
 		     MSG_LIN1, 0, TERMS, buf, MAXPLANETNAME );
 	  if ( ch != TERM_ABORT && ( ch == TERM_EXTRA || buf[0] != EOS ) )
 	    stcpn( buf, Planets[pnum].name, MAXPLANETNAME );
 	  break;
 	case 'o':
 	  /* New primary. */
-	  ch = getcx( "New planet to orbit? ",
+	  ch = mcuGetCX( "New planet to orbit? ",
 		     MSG_LIN1, 0, TERMS, buf, MAXPLANETNAME );
 	  if ( ch == TERM_ABORT || buf[0] == EOS )
 	    continue;	/* next */
 	  if ( buf[1] == '0' && buf[2] == EOS )
 	    Planets[pnum].primary = 0;
-	  else if ( gplanmatch( buf, &i ) )
+	  else if ( opPlanetMatch( buf, &i ) )
 	    Planets[pnum].primary = i;
 	  break;
 	case 'v':
 	  /* Velocity. */
-	  ch = getcx( "New velocity? ",
+	  ch = mcuGetCX( "New velocity? ",
 		     MSG_LIN1, 0, TERMS, buf, MSGMAXLINE );
 	  if ( ch == TERM_ABORT || buf[0] == EOS )
 	    continue;	/* next */
@@ -1905,7 +1935,7 @@ void oppedit(void)
 	  break;
 	case 'x':
 	  /* X coordinate. */
-	  ch = getcx( "New X coordinate? ",
+	  ch = mcuGetCX( "New X coordinate? ",
 		     MSG_LIN1, 0, TERMS, buf, MSGMAXLINE );
 	  if ( ch == TERM_ABORT || buf[0] == EOS )
 	    continue;	/* next */
@@ -1919,7 +1949,7 @@ void oppedit(void)
 	  break;
 	case 'y':
 	  /* Y coordinate. */
-	  ch = getcx( "New Y coordinate? ",
+	  ch = mcuGetCX( "New Y coordinate? ",
 		     MSG_LIN1, 0, TERMS, buf, MSGMAXLINE );
 	  if ( ch == TERM_ABORT || buf[0] == EOS )
 	    continue;	/* next */
@@ -1945,7 +1975,7 @@ void oppedit(void)
 	  break;
 	  /* Uninhabitable minutes */
 	case 'u':
-	  ch = getcx( "New uninhabitable minutes? ",
+	  ch = mcuGetCX( "New uninhabitable minutes? ",
 		     MSG_LIN1, 0, TERMS, buf, MSGMAXLINE );
 	  if ( ch == TERM_ABORT || buf[0] == EOS )
 	    continue;
@@ -1956,16 +1986,16 @@ void oppedit(void)
 	  Planets[pnum].uninhabtime = j;
 	  break;
 	case 'p':
-	  ch = getcx( "New planet to edit? ",
+	  ch = mcuGetCX( "New planet to edit? ",
 		     MSG_LIN1, 0, TERMS, buf, MAXPLANETNAME );
 	  if ( ch == TERM_ABORT || buf[0] == EOS )
 	    continue;	/* next */
-	  if ( gplanmatch( buf, &i ) )
+	  if ( opPlanetMatch( buf, &i ) )
 	    pnum = i;
 	  break;
 	case 'r':
 	  /* Radius. */
-	  ch = getcx( "New radius? ",
+	  ch = mcuGetCX( "New radius? ",
 		     MSG_LIN1, 0, TERMS, buf, MSGMAXLINE );
 	  if ( ch == TERM_ABORT || buf[0] == EOS )
 	    continue;	/* next */
@@ -2022,9 +2052,9 @@ void oppedit(void)
 /*  opplanlist - display the planet list for an operator */
 /*  SYNOPSIS */
 /*    opplanlist */
-void opplanlist(void)
+void opPlanetList(void)
 {
-  planlist( TEAM_NOTEAM, 0 );		/* we get extra info */
+  mcuPlanetList( TEAM_NOTEAM, 0 );		/* we get extra info */
 }
 
 
@@ -2047,21 +2077,21 @@ void opresign(void)
       return;
     }
 
-  if ( ! gunum( &unum, buf, -1 ) )
+  if ( ! clbGetUserNum( &unum, buf, -1 ) )
     {
       cdputs( "No such user.", MSG_LIN2, 1 );
       cdmove( 1, 1 );
       cdrefresh();
       c_sleep( 1.0 );
     }
-  else if ( confirm() )
+  else if ( mcuConfirm() )
     {
       clog("OPER: %s has resigned %s (%s)",
 	   operName,
 	   Users[unum].username,
 	   Users[unum].alias);
 
-      resign( unum, TRUE );
+      clbResign( unum, TRUE );
     }
   cdclrl( MSG_LIN1, 2 );
   
@@ -2098,7 +2128,7 @@ void oprobot(void)
   	for (i=1;i<j && xbuf[i] != EOS;i++)
 		buf[i] = (char)tolower(xbuf[i]);
 
-  if ( ! gunum( &unum, buf, -1 ) )
+  if ( ! clbGetUserNum( &unum, buf, -1 ) )
     {
       char *uptr = buf;
 				/* un-upper case first char and
@@ -2106,7 +2136,7 @@ void oprobot(void)
       if (*uptr == '@')
 	uptr++;
       uptr[0] = (char)tolower(uptr[0]);
-      if ( ! gunum( &unum, buf, -1 ) )
+      if ( ! clbGetUserNum( &unum, buf, -1 ) )
 	{
 	  cdputs( "No such user.", MSG_LIN2, 1 );
 	  return;
@@ -2140,7 +2170,7 @@ void oprobot(void)
     {
       if ( ! newrob( &snum, unum ) )
 	{
-	  c_putmsg( "Failed to create robot ship.", MSG_LIN1 );
+	  mcuPutMsg( "Failed to create robot ship.", MSG_LIN1 );
 	  break;
 	}
       
@@ -2176,7 +2206,7 @@ void oprobot(void)
   i = MSG_LIN1;
   if ( anum != num )
     i = i + 1;
-  c_putmsg( buf, i );
+  mcuPutMsg( buf, i );
   
   return;
   
@@ -2217,7 +2247,7 @@ void opstats(void)
       if ( i == 0 )
 	x = 0.0;
       else
-	x = oneplace( 100.0 * creal(ConqInfo->ccpuseconds) / creal(i) );
+	x = oneplace( 100.0 * rfix(ConqInfo->ccpuseconds) / rfix(i) );
       cprintf( lin,col,ALIGN_NONE,pfmt, 
 		LabelColor,"Conquest cpu usage:", InfoColor,x);
       
@@ -2236,7 +2266,7 @@ void opstats(void)
       if ( i == 0 )
 	x = 0.0;
       else
-	x = oneplace( 100.0 * creal(ConqInfo->dcpuseconds) / creal(i) );
+	x = oneplace( 100.0 * rfix(ConqInfo->dcpuseconds) / rfix(i) );
       cprintf( lin,col,ALIGN_NONE,pfmt, 
 		LabelColor,"Conqdriv cpu usage:", InfoColor,x);
       
@@ -2255,7 +2285,7 @@ void opstats(void)
       if ( i == 0 )
 	x = 0.0;
       else
-	x = ( 100.0 * creal(ConqInfo->rcpuseconds) / creal(i) );
+	x = ( 100.0 * rfix(ConqInfo->rcpuseconds) / rfix(i) );
       cprintf( lin, col, ALIGN_NONE, pfmt, 
 		LabelColor, "Robot cpu usage:", InfoColor, x);
       
@@ -2325,7 +2355,7 @@ void opstats(void)
       cprintf( lin,col,ALIGN_NONE, "%s",buf);
       
       cdmove( 1, 1 );
-      attrset(0);
+      uiPutColor(0);
       cdrefresh();
     }
   while ( !iogtimed( &ch, 1.0 ) ); /* until */
@@ -2338,7 +2368,7 @@ void opstats(void)
 /*  opteamlist - display the team list for an operator */
 /*  SYNOPSIS */
 /*    opteamlist */
-void opteamlist(void)
+void opTeamList(void)
 {
   
   int ch;
@@ -2346,8 +2376,8 @@ void opteamlist(void)
   cdclear();
   do /* repeat*/
     {
-      teamlist( -1 );
-      putpmt( MTXT_DONE, MSG_LIN2 );
+      mcuTeamList( -1 );
+      mcuPutPrompt( MTXT_DONE, MSG_LIN2 );
       cdrefresh();
     }
   while ( !iogtimed( &ch, 1.0 ) ); /* until */
@@ -2381,7 +2411,7 @@ void opuadd(void)
       cdclrl( MSG_LIN1, 1 );
       return;
     }
-  if ( gunum( &unum, name, -1 ) ) /* don't want to use ptr here */
+  if ( clbGetUserNum( &unum, name, -1 ) ) /* don't want to use ptr here */
     {
       cdputs( "That user is already enrolled.", MSG_LIN2, 1 );
       cdmove( 1, 1 );
@@ -2429,7 +2459,7 @@ void opuadd(void)
   appstr( nameptr, buf );
   buf[i] = (char)toupper( buf[i] );
   buf[MAXUSERPNAME] = EOS;
-  if ( ! c_register( nameptr, buf, team, &unum ) )
+  if ( ! clbRegister( nameptr, buf, team, &unum ) )
     {
       cdputs( "Error adding new user.", MSG_LIN2, 1 );
       cdmove( 0, 0 );
@@ -2467,22 +2497,23 @@ void opuedit(void)
   static char *prompt2 = "any other key to quit.";
   static char *rprompt = "Use arrow keys to position, [SPACE] to modify, [TAB] to change password";
   char *promptptr;
+
   cdclrl( MSG_LIN1, 2 );
-  attrset(InfoColor);
-  ch = getcx( "Edit which user: ", MSG_LIN1, 0, TERMS, buf, MAXUSERNAME );
+  uiPutColor(InfoColor);
+  ch = mcuGetCX( "Edit which user: ", MSG_LIN1, 0, TERMS, buf, MAXUSERNAME );
   if ( ch == TERM_ABORT )
     {
       cdclrl( MSG_LIN1, 2 );
-	  attrset(0);
+	  uiPutColor(0);
       return;
     }
   /*  delblanks( buf );*/
 
-  if ( ! gunum( &unum, buf, -1 ) )
+  if ( ! clbGetUserNum( &unum, buf, -1 ) )
     {
       cdclrl( MSG_LIN1, 2 );
       cdputs( "Unknown user.", MSG_LIN1, 1 );
-	  attrset(0);
+	  uiPutColor(0);
       cdmove( 1, 1 );
       cdrefresh();
       c_sleep( 1.0 );
@@ -2564,6 +2595,7 @@ void opuedit(void)
       for ( i = 0; i < MAXOOPTIONS; i++ )
 	{
 	  cprintf(lin+i,tcol,ALIGN_NONE,"#%d#%17d:", LabelColor,i);
+
 	  if ( Users[unum].ooptions[i] )
 	    cprintf(lin+i,dcol,ALIGN_NONE,"#%d#%c", GreenLevelColor,'T');
 	  else
@@ -2778,7 +2810,7 @@ void opuedit(void)
 	    {
 	      /* Pseudonym. */
 	      cdclrl( MSG_LIN2, 1 );
-	      ch = getcx( "Enter a new pseudonym: ",
+	      ch = mcuGetCX( "Enter a new pseudonym: ",
 			 MSG_LIN2, 0, TERMS, buf, MAXUSERPNAME );
 	      if ( ch != TERM_ABORT &&
 		  ( buf[0] != EOS || ch == TERM_EXTRA ) )
@@ -2788,12 +2820,12 @@ void opuedit(void)
 	    {
 	      /* Username. */
 	      cdclrl( MSG_LIN2, 1 );
-	      ch = getcx( "Enter a new username: ",
+	      ch = mcuGetCX( "Enter a new username: ",
 			 MSG_LIN2, 0, TERMS, buf, MAXUSERNAME );
 	      if ( ch != TERM_ABORT && buf[0] != EOS)
 	      {
 		delblanks( buf );
-		if ( ! gunum( &i, buf, -1 ) )
+		if ( ! clbGetUserNum( &i, buf, -1 ) )
 		  stcpn( buf, Users[unum].username, MAXUSERNAME );
 		else
 		  {
@@ -2815,7 +2847,7 @@ void opuedit(void)
 	    {
 	      /* Multiple count. */
 	      cdclrl( MSG_LIN2, 1 );
-	      ch = getcx( "Enter new multiple count: ",
+	      ch = mcuGetCX( "Enter new multiple count: ",
 			 MSG_LIN2, 0, TERMS, buf, MSGMAXLINE );
 	      if ( ch != TERM_ABORT && buf[0] != EOS )
 		{
@@ -2903,7 +2935,7 @@ void watch(void)
 	    if ( dgrand( msgrand, &now ) >= NEWMSG_GRAND )
 		if ( getamsg( MSG_GOD, &ConqInfo->glastmsg ) )
 		  {
-		    readmsg( MSG_GOD, ConqInfo->glastmsg, RMsg_Line );
+		    mcuReadMsg( MSG_GOD, ConqInfo->glastmsg, RMsg_Line );
 #if defined(OPER_MSG_BEEP)
 		    if (Msgs[ConqInfo->glastmsg].msgfrom != MSG_GOD)
 		      cdbeep();
@@ -2942,7 +2974,7 @@ void watch(void)
 		      if ( Doomsday->status == DS_LIVE )
 			Doomsday->status = DS_OFF;
 		      else
-			doomsday();
+			clbDoomsday();
 		    }
 		  else
 		    cdbeep();
@@ -2959,14 +2991,21 @@ void watch(void)
 		case 'k':
 		  kiss(Context.snum, TRUE);
 		  break;
+                case 'M':		/* strategic/tactical map */
+                  if (SMAP(Context.snum))
+                    SFCLR(Context.snum, SHIP_F_MAP);
+                  else
+                    SFSET(Context.snum, SHIP_F_MAP);
+
+                  break;
 		case 'm':
-		  clntSendMsg( MSG_GOD, TRUE, FALSE );
+		  cucSendMsg( MSG_GOD, TRUE, FALSE );
 		  break;
 		case 'r':  /* just for fun - dwp */
 		  oprobot();
 		  break;
 		case 'L':
-		  review( MSG_GOD, ConqInfo->glastmsg );
+		  mcuReviewMsgs( MSG_GOD, ConqInfo->glastmsg );
 		  break;
 		case 0x0c:
 		  operStopTimer();
@@ -3041,13 +3080,13 @@ void watch(void)
 		  break;
 		case '/':                /* ship list - dwp */
 		  operStopTimer();
-		  playlist( TRUE, FALSE, 0 );
+		  mcuPlayList( TRUE, FALSE, 0 );
 		  Context.redraw = TRUE;
 		  operSetTimer();
 		  break;
 		case '\\':               /* big ship list - dwp */
 		  operStopTimer();
-		  playlist( TRUE, TRUE, 0 );
+		  mcuPlayList( TRUE, TRUE, 0 );
 		  Context.redraw = TRUE;
 		  operSetTimer();
 		  break;
@@ -3072,7 +3111,7 @@ void watch(void)
 
 			  for (i=1; i <= MAXSHIPS; i++)
 			    {
-			      if (stillalive(i))
+			      if (clbStillAlive(i))
 				{
 				  foundone = TRUE;
 				}
@@ -3113,7 +3152,7 @@ void watch(void)
 		      Context.redraw = TRUE;
 		      
 		      if (live_ships)
-			if ((snum > 0 && stillalive(snum)) || 
+			if ((snum > 0 && clbStillAlive(snum)) || 
 			    (snum == DISPLAY_DOOMSDAY && Doomsday->status == DS_LIVE))
 			  {
 			    Context.snum = snum;
@@ -3149,7 +3188,7 @@ void watch(void)
 
 			  for (i=1; i <= MAXSHIPS; i++)
 			    {
-			      if (stillalive(i))
+			      if (clbStillAlive(i))
 				{
 				  foundone = TRUE;
 				}
@@ -3191,7 +3230,7 @@ void watch(void)
 		      Context.redraw = TRUE;
 		      
 		      if (live_ships)
-			if ((snum > 0 && stillalive(snum)) || 
+			if ((snum > 0 && clbStillAlive(snum)) || 
 			    (snum == DISPLAY_DOOMSDAY && Doomsday->status == DS_LIVE))
 			  {
 			    Context.snum = snum;
@@ -3218,7 +3257,7 @@ void watch(void)
 		  break;
 		default:
 		  cdbeep();
-		  c_putmsg( "Type h for help.", MSG_LIN2 );
+		  mcuPutMsg( "Type h for help.", MSG_LIN2 );
 		  break;
 		}
 	      /* Disable messages for awhile. */
@@ -3354,7 +3393,7 @@ void dowatchhelp(void)
   tlin++;
   cprintf(tlin,col,ALIGN_NONE,sfmt, "/", "player list");
 
-  putpmt( MTXT_DONE, MSG_LIN2 );
+  mcuPutPrompt( MTXT_DONE, MSG_LIN2 );
   cdrefresh();
   while ( ! iogtimed( &ch, 1.0 ) )
     ;
@@ -3432,7 +3471,7 @@ int DoInit(char InitChar, int cmdline)
   switch(InitChar)
     {
     case 'e': 
-      initeverything();
+      clbInitEverything();
       *CBlockRevision = COMMONSTAMP;
 
       if (cmdline == TRUE)
@@ -3444,7 +3483,7 @@ int DoInit(char InitChar, int cmdline)
       break;
 
     case 'z': 
-      zeroeverything();
+      clbZeroEverything();
 
       if (cmdline == TRUE)
 	{
@@ -3455,7 +3494,7 @@ int DoInit(char InitChar, int cmdline)
       break;
 
     case 'u': 
-      inituniverse();
+      clbInitUniverse();
       *CBlockRevision = COMMONSTAMP;
 
       if (cmdline == TRUE)
@@ -3467,7 +3506,7 @@ int DoInit(char InitChar, int cmdline)
       break;
 
     case 'g': 
-      initgame();
+      clbInitGame();
       *CBlockRevision = COMMONSTAMP;
 
       if (cmdline == TRUE)
@@ -3479,7 +3518,7 @@ int DoInit(char InitChar, int cmdline)
       break;
 
     case 'p': 
-      initplanets();
+      clbInitPlanets();
       *CBlockRevision = COMMONSTAMP;
 
       if (cmdline == TRUE)
@@ -3491,7 +3530,7 @@ int DoInit(char InitChar, int cmdline)
       break;
 
     case 's': 
-      clearships();
+      clbClearShips();
       *CBlockRevision = COMMONSTAMP;
 
       if (cmdline == TRUE)
@@ -3503,7 +3542,7 @@ int DoInit(char InitChar, int cmdline)
       break;
 
     case 'm': 
-      initmsgs();
+      clbInitMsgs();
       *CBlockRevision = COMMONSTAMP;
 
       if (cmdline == TRUE)
@@ -3528,7 +3567,7 @@ int DoInit(char InitChar, int cmdline)
       break;
 
     case 'r': 
-      initrobots();
+      clbInitRobots();
       *CBlockRevision = COMMONSTAMP;
 
       if (cmdline == TRUE)
@@ -3625,7 +3664,7 @@ void operSetTimer(void)
 {
   static struct sigaction Sig;
   
-#ifdef HAS_SETITIMER
+#ifdef HAVE_SETITIMER
   struct itimerval itimer;
 #endif
   
@@ -3639,7 +3678,7 @@ void operSetTimer(void)
       exit(errno);
     }
   
-#ifdef HAS_SETITIMER
+#ifdef HAVE_SETITIMER
 
   if (Context.updsec >= 1 && Context.updsec <= 10)
     {
@@ -3678,7 +3717,7 @@ void operSetTimer(void)
 /*    operStopTimer */
 void operStopTimer(void)
 {
-#ifdef HAS_SETITIMER
+#ifdef HAVE_SETITIMER
   struct itimerval itimer;
 #endif
   
@@ -3687,7 +3726,7 @@ void operStopTimer(void)
 
   signal(SIGALRM, SIG_IGN);
   
-#ifdef HAS_SETITIMER
+#ifdef HAVE_SETITIMER
   itimer.it_value.tv_sec = itimer.it_interval.tv_sec = 0;
   itimer.it_value.tv_usec = itimer.it_interval.tv_usec = 0;
   
