@@ -4,7 +4,7 @@
  *
  * conquestd - the Conquest server/client driver
  *
- * $Id: conquestd.c,v 1.11 2004/01/12 03:59:01 jon Exp $
+ * $Id: conquestd.c,v 1.25 2004/12/26 08:19:31 jon Exp $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -14,16 +14,18 @@
 
 #include "conqdef.h"
 #include "conqcom.h"
+#include "conqlb.h"
 #include "context.h"
 #include "conf.h"
 #include "global.h"
 #include "color.h"
 #include "record.h"
 #include "ibuf.h"
-#include "display.h"
+#include "sem.h"
 
 #include "conqnet.h"
 #include "packet.h"
+#include "udp.h"
 
 #define SERVER_NOEXTERN
 #include "server.h"
@@ -49,8 +51,8 @@ static char *myServerName = NULL; /* to meta */
 cpHello_t chello;		/* client hello info we want to keep */
 ServerInfo_t sInfo;
 
-int hello(void);		/* meet and greet the client */
-int updateClient(void);
+static int hello(void);		/* meet and greet the client */
+int updateClient(int force);
 void updateProc(void);
 void startUpdate(void);
 void stopUpdate(void);
@@ -58,6 +60,9 @@ void stopUpdate(void);
 void catchSignals(void);
 void handleSignal(int sig);
 void conqend(void);
+int welcome( int *unum );
+void menu(void);
+int play(void);
 
 void printUsage()
 {
@@ -120,7 +125,7 @@ void checkMaster(void)
 
   signal(SIGCLD, SIG_IGN);	/* allow children to die */
 
-  if (!CheckPid(ConqInfo->conqservPID))
+  if (!checkPID(ConqInfo->conqservPID))
     {				/* see if one is really running */
       /* if we are here, we will be the listener */
       PVLOCK(&ConqInfo->lockword);
@@ -168,6 +173,7 @@ void checkMaster(void)
   
   /* set the maximum connections we will fall behind */
   listen( s, LISTEN_BACKLOG );
+
   
   /* go into infinite loop waiting for new connections */
   while (TRUE) 
@@ -206,6 +212,7 @@ void checkMaster(void)
           if ( fork() == 0 ) 
             {			/* child - client driver */
               sInfo.sock = t;
+              pktSetNodelay(sInfo.sock);
               memset(sInfo.remotehost, 0, MAXHOSTNAME);
               getHostname(sInfo.sock, sInfo.remotehost, MAXHOSTNAME - 1);
               
@@ -233,6 +240,9 @@ int main(int argc, char *argv[])
   progName = argv[0];
   sInfo.state = SVR_STATE_PREINIT;
   sInfo.sock = -1;
+  sInfo.usock = -1;
+  sInfo.doUDP = FALSE;
+  sInfo.tryUDP = TRUE;
   sInfo.clientDead = TRUE;
   sInfo.isMaster = FALSE;
   sInfo.isLoggedIn = FALSE;
@@ -277,15 +287,9 @@ int main(int argc, char *argv[])
   /* clear out our stored packets */
   spktInit();
 
-  if ((ConquestUID = GetUID(ROOT_USER)) == ERR)
+  if ((ConquestGID = getConquestGID()) == ERR)
     {
-      fprintf(stderr, "%s: GetUID() failed\n", progName);
-      exit(1);
-    }
-  
-  if ((ConquestGID = GetConquestGID()) == ERR)
-    {
-      fprintf(stderr, "%s: GetConquestGID() failed\n", progName);
+      fprintf(stderr, "%s: getConquestGID() failed\n", progName);
       exit(1);
     }
   
@@ -297,9 +301,9 @@ int main(int argc, char *argv[])
     {
       int myuid;
 
-      if ((myuid = GetUID(myuidname)) == ERR)
+      if ((myuid = getUID(myuidname)) == ERR)
         {
-          fprintf(stderr, "%s: GetUID(%s) failed\n", progName, myuidname);
+          fprintf(stderr, "%s: getUID(%s) failed\n", progName, myuidname);
           exit(1);
         }
 
@@ -339,12 +343,12 @@ int main(int argc, char *argv[])
 #endif
   
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() getting semephores - GetSem()", __FILE__, __LINE__);
+  clog("%s@%d: main() getting semephores - semInit()", __FILE__, __LINE__);
 #endif
   
-  if (GetSem() == ERR)
+  if (semInit() == ERR)
     {
-      fprintf(stderr, "GetSem() failed to get semaphores. exiting.\n");
+      fprintf(stderr, "semInit() failed to get semaphores. exiting.\n");
       exit(1);
     }
   
@@ -373,7 +377,7 @@ int main(int argc, char *argv[])
   Context.histslot = ERR;
   Context.lasttang = Context.lasttdist = 0;
   Context.lasttarg[0] = EOS;
-  Context.updsec = 2;		/* two per second default update rate */
+  Context.updsec = 10;		/* 10 per second default update rate */
 
 
   /* if daemon mode requested, fork off and detach */
@@ -480,6 +484,15 @@ int main(int argc, char *argv[])
 /* responsible for updating the client */
 void updateProc(void)
 {
+#if 0
+  static Unsgn32 lastms = 0;
+  Unsgn32 millis = clbGetMillis();
+
+  if ((millis - lastms) > 100)
+    clog("millisdiff = %u", (millis - lastms));
+  lastms = millis;
+#endif
+
   /* Don't do anything if we're not supposed to. */
   if (sInfo.state != SVR_STATE_PLAY)
     return;
@@ -489,13 +502,13 @@ void updateProc(void)
   drcheck();			/* check the driver */  
 
   /* update client view of the universe */
-  updateClient();
+  updateClient(FALSE);
 
   recordUpdateFrame();
 
   /* check for and send any new messages */
   if ( getamsg( Context.snum, &Ships[Context.snum].lastmsg ) )
-    sendMessage(sInfo.sock, &(Msgs[Ships[Context.snum].lastmsg]));
+    sendMessage(&(Msgs[Ships[Context.snum].lastmsg]));
 
   /* Schedule for next time. */
   startUpdate();
@@ -508,7 +521,7 @@ void startUpdate(void)
 {
   static struct sigaction Sig;
 
-#ifdef HAS_SETITIMER
+#ifdef HAVE_SETITIMER
   struct itimerval itimer;
 #endif
 
@@ -522,7 +535,7 @@ void startUpdate(void)
       exit(errno);
     }
   
-#ifdef HAS_SETITIMER
+#ifdef HAVE_SETITIMER
   if (Context.updsec >= 1 && Context.updsec <= 10)
     {
       if (Context.updsec == 1)
@@ -555,13 +568,13 @@ void startUpdate(void)
 
 void stopUpdate(void)
 {
-#ifdef HAS_SETITIMER
+#ifdef HAVE_SETITIMER
   struct itimerval itimer;
 #endif
   
   signal(SIGALRM, SIG_IGN);
   
-#ifdef HAS_SETITIMER
+#ifdef HAVE_SETITIMER
   itimer.it_value.tv_sec = itimer.it_interval.tv_sec = 0;
   itimer.it_value.tv_usec = itimer.it_interval.tv_usec = 0;
   
@@ -589,6 +602,7 @@ int capentry( int snum, int *system )
   cpCommand_t *ccmd;
   Unsgn8 buf[PKT_MAXSIZE];
   Unsgn8 esystem = 0;
+  int sockl[2] = {sInfo.sock, sInfo.usock};
   
   /* First figure out which systems we can enter from. */
   for ( i = 0; i < NUMPLAYERTEAMS; i = i + 1 )
@@ -633,13 +647,13 @@ int capentry( int snum, int *system )
 		     Context.unum, esystem))
     return FALSE;
 
-  while ( stillalive( Context.snum ) )
+  while ( clbStillAlive( Context.snum ) )
     {
 
       /* now we wait for another ENTER command packet with it's detail member
 	 indicating the desired system. */
 
-      if ((pkttype = waitForPacket(PKT_FROMCLIENT, sInfo.sock, CP_COMMAND,
+      if ((pkttype = waitForPacket(PKT_FROMCLIENT, sockl, CP_COMMAND,
 				   buf, PKT_MAXSIZE, 1, NULL)) < 0)
         {
 	  clog("conquestd:capentry: waitforpacket returned %d", pkttype); 
@@ -680,7 +694,7 @@ int capentry( int snum, int *system )
       return TRUE;
     }
 
-  return FALSE;	    /* can get here because of stillalive() */
+  return FALSE;	    /* can get here because of clbStillAlive() */
   
 }
 
@@ -695,6 +709,7 @@ void dead( int snum, int leave )
   int i, j, kb, now, entertime; 
   Unsgn8 flags = SPCLNTSTAT_FLAG_NONE; /* for clientstat msg */
   char buf[PKT_MAXSIZE];	/* gen purpose */
+  int sockl[2] = {sInfo.sock, sInfo.usock};
   
   /* If something is wrong, don't do anything. */
   if ( snum < 1 || snum > MAXSHIPS )
@@ -711,7 +726,7 @@ void dead( int snum, int leave )
   i = 0;
   while ( dgrand( entertime, &now ) < TORPEDOWAIT_GRAND )
     {
-      updateClient();
+      updateClient(FALSE);
       i = 0;
       for ( j = 0; j < MAXTORPS; j = j + 1 )
 	if ( Ships[snum].torps[j].status == TS_DETONATE )
@@ -734,11 +749,11 @@ void dead( int snum, int leave )
   appship( snum, buf );
   clog("INFO: dead: %s was killed by %d.", buf, kb);
   
-  updateClient();
+  updateClient(FALSE);
   for ( i=0; i<10 && Ships[snum].status == SS_DYING; i++ )
     {
       c_sleep( (1.0 / (real)Context.updsec) );
-      updateClient();
+      updateClient(FALSE);
     }
 
   /* if you conquered the universe, let the client know, and wait for
@@ -777,14 +792,14 @@ void dead( int snum, int leave )
   /*  Ships[snum].killedby = 0;*/
 
   /* let the client know. */
-  updateClient();
+  updateClient(FALSE);
 
   /* if conquered, wait for the cpMessage_t */
   if (kb == KB_CONQUER)
     {
-      if (waitForPacket(PKT_FROMCLIENT, sInfo.sock, CP_MESSAGE, 
+      if (waitForPacket(PKT_FROMCLIENT, sockl, CP_MESSAGE, 
 			buf, PKT_MAXSIZE,
-			(60 * 2), NULL) <= 0)
+			(60 * 5), NULL) <= 0)
 	{			/* error or timeout.  gen lastwords */
 	  robreply(buf);
 	  strncpy(ConqInfo->lastwords, buf, MAXLASTWORDS);
@@ -811,9 +826,70 @@ void dead( int snum, int leave )
 }
 
 /* send all pertinent data, and any users attached to them. */
-int updateClient(void)
+int updateClient(int force)
 {
   int i,j;
+  static int sentallusers = FALSE; /* we will send all user data once. */
+  static time_t oldtime = 0;
+  time_t newtime = getnow(NULL, 0);
+  int seciter = FALSE;
+  static time_t histtime = 0;   /* timers that try to save some time() */
+  static time_t infotime = 0;
+  static time_t teamtime = 0;
+  int dohist = FALSE;
+  int doinfo = FALSE;
+  int doteam = FALSE;
+
+  if (force)
+    {                           /* we need to reload everything */
+      oldtime = 0;
+      histtime = 0;   
+      infotime = 0;
+      teamtime = 0;
+      sentallusers = FALSE;
+    }
+     
+  
+  /* some things really should not be checked every update iter */
+  if (oldtime != newtime)
+    {
+      seciter = TRUE;
+      oldtime = newtime;
+    }
+
+  /* hist */
+  if ((abs((unsigned int)newtime - (unsigned int)histtime) >
+       HISTORY_UPDATE_INTERVAL))
+    {
+      dohist = TRUE;
+      histtime = newtime;
+    }
+
+  /* info */
+  if ((abs((unsigned int)newtime - (unsigned int)infotime) >
+       CONQINFO_UPDATE_INTERVAL))
+    {
+      doinfo = TRUE;
+      infotime = newtime;
+    }
+
+  /* team */
+  if ((abs((unsigned int)newtime - (unsigned int)teamtime) >
+       TEAM_UPDATE_INTERVAL))
+    {
+      doteam = TRUE;
+      teamtime = newtime;
+    }
+
+
+  if (!sentallusers)
+    {                           /* send all valid user data the first time */
+      sentallusers = TRUE;
+      for (i=0; i<MAXUSERS; i++)
+        if (Users[i].live)
+          if (!sendUser(sInfo.sock, i))
+            return FALSE;
+    }
 
   for (i=1; i<=MAXSHIPS; i++)
     {
@@ -827,31 +903,38 @@ int updateClient(void)
       /* we only send user data for active ships. */
       if (Ships[i].status != SS_OFF)
 	{
-	  if (!sendUser(sInfo.sock, Ships[i].unum))
-	    {
-	      return FALSE;
-	    }
-	}
+          if (seciter)
+            {
+              if (!sendUser(sInfo.sock, Ships[i].unum))
+                {
+                  return FALSE;
+                }
+            }
+        }
     }
 
   for (i=1; i<=NUMPLANETS; i++)
+    sendPlanet(sInfo.sock, i, force);
+
+  if (doteam)
+    for (i=0; i<NUMALLTEAMS; i++)
+      sendTeam(sInfo.sock, i, FALSE);
+
+  if (doinfo)
+    sendConqInfo(sInfo.sock, FALSE);
+
+  if (dohist)
     {
-      if (Planets[i].real)
-	sendPlanet(sInfo.sock, i);
+      for (i=0; i<MAXHISTLOG; i++)
+        {
+          if (History[i].histunum >= 0)
+            sendUser(sInfo.sock, History[i].histunum);
+          
+          sendHistory(sInfo.sock, i);
+        }
     }
 
-  for (i=0; i<NUMALLTEAMS; i++)
-    sendTeam(sInfo.sock, i, FALSE);
-
-  sendConqInfo(sInfo.sock, FALSE);
-
-  for (i=0; i<MAXHISTLOG; i++)
-    {
-      if (History[i].histunum >= 0)
-        sendUser(sInfo.sock, History[i].histunum);
-
-      sendHistory(sInfo.sock, i);
-    }
+  sendDoomsday(sInfo.sock);
 
   return TRUE;
 }
@@ -1013,6 +1096,9 @@ void handleSimpleCmdPkt(cpCommand_t *ccmd)
 
     case CPCMD_RELOAD:
       procReload(ccmd);
+      clbBlockAlarm();
+      updateClient(TRUE);
+      clbUnblockAlarm();
 
       break;
 
@@ -1023,6 +1109,12 @@ void handleSimpleCmdPkt(cpCommand_t *ccmd)
       /* NOTREACHED */
       break;
 
+    case CPCMD_PING:
+      clbBlockAlarm();
+      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_PINGRESP, NULL);
+      clbUnblockAlarm();
+      break;
+
     default:
       clog("conquestd: handleSimpleCmdPkt(): unexpected command code %d",
 	   cmd);
@@ -1054,6 +1146,7 @@ void menu(void)
   int pkttype;
   Unsgn8 buf[PKT_MAXSIZE];
   cpCommand_t *ccmd;
+  int sockl[2] = {sInfo.sock, sInfo.usock};
 
   catchSignals();	/* enable trapping of interesting signals */
   
@@ -1063,9 +1156,9 @@ void menu(void)
   initstats( &Ships[Context.snum].ctime, &Ships[Context.snum].etime );
   
   /* Log this entry into the Game. */
-  Context.histslot = loghist( Context.unum );
+  Context.histslot = clbLogHist( Context.unum );
   
-  /* Set up a few ship characteristics here rather than in initship(). */
+  /* Set up a few ship characteristics here rather than in clbInitShip(). */
   Ships[Context.snum].unum = Context.unum;
   Ships[Context.snum].team = Users[Context.unum].team;
   Ships[Context.snum].shiptype = Teams[Ships[Context.snum].team].shiptype;
@@ -1104,7 +1197,7 @@ void menu(void)
   
   do                 
     {
-      if (!updateClient())	/* sends packets */
+      if (!updateClient(FALSE))	/* sends packets */
 	{
 	  freeship();
 	  return;
@@ -1146,7 +1239,7 @@ void menu(void)
       /* Reset up the destruct fuse. */
       Ships[Context.snum].sdfuse = -TIMEOUT_PLAYER;
       
-      if ((pkttype = waitForPacket(PKT_FROMCLIENT, sInfo.sock, PKT_ANYPKT,
+      if ((pkttype = waitForPacket(PKT_FROMCLIENT, sockl, PKT_ANYPKT,
 			buf, PKT_MAXSIZE, 1, NULL)) < 0)
 	{
 	  freeship();
@@ -1195,7 +1288,7 @@ void menu(void)
 		     Ships[i].status == SS_ENTERING) && 
 		     Ships[i].unum == Context.unum))
 		  {
-		    resign( Context.unum, FALSE );
+		    clbResign( Context.unum, FALSE );
 		    Ships[Context.snum].status = SS_OFF;
 		    exit(0);	/* exit here */
 		  }
@@ -1216,7 +1309,7 @@ void menu(void)
       
       sleepy = 0;
     }
-  while ( stillalive( Context.snum ) &&  !Context.leave );
+  while ( clbStillAlive( Context.snum ) &&  !Context.leave );
   
   /* Make our ship available for others to use. */
   if ( Ships[Context.snum].status == SS_RESERVED )
@@ -1365,14 +1458,14 @@ int newship( int unum, int *snum )
   /* If necessary, initalize the ship */
   if ( fresh )
     {
-      initship( *snum, unum );
+      clbInitShip( *snum, unum );
       
       /* Randomly position the ship near the home sun (or planet). */
       if ( Planets[Teams[system].homeplanet].primary == Teams[system].homesun )
 	i = Teams[system].homesun;
       else
 	i = Teams[system].homeplanet;
-      putship( *snum, Planets[i].x, Planets[i].y );
+      clPutShip( *snum, Planets[i].x, Planets[i].y );
       Ships[*snum].dhead = rnduni( 0.0, 359.9 );
       Ships[*snum].head = Ships[*snum].dhead;
       Ships[*snum].dwarp = (real) rndint( 2, 5 ) ;/* #~~~ this is a kludge*/
@@ -1395,7 +1488,7 @@ int newship( int unum, int *snum )
   
   
   /* Straighten out the ships deltas. */
-  fixdeltas( *snum );
+  clbFixDeltas( *snum );
   
   /* Finally, turn the ship on. */
   Ships[*snum].status = SS_LIVE;
@@ -1411,7 +1504,7 @@ int newship( int unum, int *snum )
 /*  play - play the game (PLAY) */
 /*  SYNOPSIS */
 /*    play */
-int play()
+int play(void)
 {
   int laststat, now;
   int didsomething;             /* update immediately if we did anything */
@@ -1419,6 +1512,7 @@ int play()
   char msgbuf[128];
   int pkttype;
   Unsgn8 buf[PKT_MAXSIZE];
+  int sockl[2] = {sInfo.sock, sInfo.usock};
 
   /* Can't carry on without a vessel. */
   if ( (rv = newship( Context.unum, &Context.snum )) != TRUE)
@@ -1459,19 +1553,19 @@ int play()
 	  Context.snum,
 	  Ships[Context.snum].alias);
   
-  stormsg(MSG_COMP, MSG_ALL, msgbuf);
+  clbStoreMsg(MSG_COMP, MSG_ALL, msgbuf);
   
 
   /* client updates will be handled by updateProc */
   /* While we're alive, field commands and process them. */
-  while ( stillalive( Context.snum ) )
+  while ( clbStillAlive( Context.snum ) )
     {
       /* Make sure we still control our ship. */
       if ( Ships[Context.snum].pid != Context.pid )
 	break;
 
       didsomething = 0;
-      if ((pkttype = waitForPacket(PKT_FROMCLIENT, sInfo.sock, PKT_ANYPKT,
+      if ((pkttype = waitForPacket(PKT_FROMCLIENT, sockl, PKT_ANYPKT,
 				   buf, PKT_MAXSIZE, 0, NULL)) < 0)
 	{
 	  if (errno != EINTR)
@@ -1523,9 +1617,9 @@ int play()
 
       if (didsomething)         /* update immediately if we did something */
         {
-          stopUpdate();
-          updateClient();
-          startUpdate();
+          clbBlockAlarm();
+          updateClient(FALSE);
+          clbUnblockAlarm();
         }
 
       grand( &Context.msgrand );
@@ -1538,7 +1632,10 @@ int play()
 	  laststat = now;
 	}
 
-      c_sleep(ITER_SECONDS);
+      if (didsomething)         
+        continue;               /* see if there is another pkt */
+
+      c_sleep(0.05);
     }
   
   conqstats( Context.snum );
@@ -1548,7 +1645,7 @@ int play()
 
 
   stopUpdate();
-  updateClient();	/* one last, to be sure. */
+  updateClient(FALSE);	/* one last, to be sure. */
   sendConqInfo(sInfo.sock, TRUE);
   c_sleep( 2.0 );
   clog("INFO: ship %d died, calling dead()", Context.snum);
@@ -1576,7 +1673,7 @@ int welcome( int *unum )
 
   sInfo.isLoggedIn = TRUE;
 
-  if ( ! gunum( unum, name, 0 ) )
+  if ( ! clbGetUserNum( unum, name, 0 ) )
     {				
       flags |= SPCLNTSTAT_FLAG_NEW;
       /* Must be a new player. */
@@ -1596,14 +1693,14 @@ int welcome( int *unum )
       appstr( name, cbuf );
       cbuf[i] = (char)toupper( cbuf[i] );
 
-      if ( ! c_register( name, cbuf, team, unum ) )
+      if ( ! clbRegister( name, cbuf, team, unum ) )
 	{
 	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_REGISTER,
                   NULL);
 	  return ( FALSE );
 	}
 
-      clog("conquestd: c_register COMPLETE!!!! unum = %d, team = %d\n", 
+      clog("conquestd: clbRegister COMPLETE!!!! unum = %d, team = %d\n", 
 	   *unum, team);
 
 				/* copy in the password */
@@ -1624,7 +1721,7 @@ int welcome( int *unum )
     }
 
   /* Can't play without a ship. */
-  if ( ! findship( &Context.snum ) )
+  if ( ! clbFindShip( &Context.snum ) )
     {
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_NOSHIP,
 	      NULL);
@@ -1647,13 +1744,27 @@ int welcome( int *unum )
 }
 
 
-int hello(void)
+static int hello(void)
 {
   spHello_t shello;
   Unsgn8 buf[PKT_MAXSIZE];
   char cbuf[MESSAGE_SIZE * 2];
   int pkttype;
   extern char *ConquestVersion, *ConquestDate;
+  int rv;
+  struct timeval tv;
+  fd_set readfds;
+  struct sockaddr_in usa;	/* internet socket addr. structure - udp */
+  cpAck_t *cpack;
+  int sockl[2] = {sInfo.sock, sInfo.usock};
+
+  /* open a UDP socket and bind to it */
+  if ((sInfo.usock = udpOpen(listenPort, &usa)) < 0)
+    {
+      clog("NET: SERVER hello: udpOpen() failed: %s", strerror(errno));
+      sInfo.usock = -1;
+      sInfo.tryUDP = FALSE;
+    }
 
   /* first loadup and send a server hello */
   shello.type = SP_HELLO;
@@ -1673,28 +1784,63 @@ int hello(void)
 
   if (!writePacket(PKT_TOCLIENT, sInfo.sock, (Unsgn8 *)&shello))
     {
-      clog("hello: write shello failed\n");
+      clog("NET: SERVER: hello: write shello failed\n");
       return FALSE;
     }
 
-  clog("HELLO: sent server hello to client");
+  clog("NET: SERVER: hello: sent server hello to client");
+
+  if (sInfo.tryUDP)
+    {
+      /* wait a few seconds to see if client sends a udp */
+      tv.tv_sec = 5;
+      tv.tv_usec = 0;
+      FD_ZERO(&readfds);
+      FD_SET(sInfo.usock, &readfds);
+      if ((rv = select(sInfo.usock+1, &readfds, NULL, NULL, &tv)) <= 0)
+        {
+          if (rv == 0)
+            clog("NET: SERVER: hello: udp select timed out. No UDP");
+          else
+            clog("NET: SERVER: hello: udp select failed: %s", strerror(errno));
+
+          sInfo.tryUDP = FALSE;
+        }
+      else
+        {
+          if (FD_ISSET(sInfo.usock, &readfds))
+            {                       /* get the packet, almost done negotiating udp */
+              rv = udpRecv(sInfo.usock, buf, PKT_MAXSIZE, &sInfo.clntaddr);
+              clog("NET: SERVER: hello: got %d UDP bytes from client port %d", rv, 
+                   (int)ntohs(sInfo.clntaddr.sin_port));
+              
+              if (connect(sInfo.usock, (const struct sockaddr *)&sInfo.clntaddr, 
+                          sizeof(sInfo.clntaddr)) < 0)
+                {
+                  clog("NET: SERVER: hello: udp connect() failed: %s", strerror(errno));
+                  sInfo.tryUDP = FALSE;
+                }
+            }
+        }
+    }
+
   /* now we want a client hello in response */
-  if ((pkttype = readPacket(PKT_FROMCLIENT, sInfo.sock, buf, PKT_MAXSIZE, 10)) < 0)
+  if ((pkttype = readPacket(PKT_FROMCLIENT, sockl, buf, PKT_MAXSIZE, 60)) < 0)
   {
-    clog("HELLO: read client hello failed, pkttype = %d",
+    clog("NET: SERVER: hello: read client hello failed, pkttype = %d",
          pkttype);
     return FALSE;
   }
 
   if (pkttype == 0)
   {
-    clog("HELLO: read client hello: timeout.\n");
+    clog("NET: SERVER: hello: read client hello: timeout.\n");
     return FALSE;
   }
 
   if (pkttype != CP_HELLO)
   {
-    clog("HELLO: read client hello: wrong packet type %d\n", pkttype);
+    clog("NET: SERVER: hello: read client hello: wrong packet type %d\n", pkttype);
     return FALSE;
   }
 
@@ -1707,9 +1853,7 @@ int hello(void)
   chello.clientname[CONF_SERVER_NAME_SZ - 1] = 0;
   chello.clientver[CONF_SERVER_NAME_SZ - 1] = 0;
 
-  clog("HELLO: CLIENT: cname = '%s'\n"
-       "               cver = '%s'\n"
-       "               upd: %d, protv = 0x%04hx, cmnr = %d",
+  clog("CLIENTID:%s:%s:%d:0x%04hx:%d",
        chello.clientname, 
        chello.clientver,
        chello.updates, 
@@ -1719,35 +1863,62 @@ int hello(void)
   /* do some checks - send a NAK and fail if things aren't cool */
   if (chello.protover != PROTOCOL_VERSION)
     {
-      sprintf(cbuf, "HELLO: SVR: protocol mismatch, expect 0x%04x, got 0x%04x",
+      sprintf(cbuf, "SERVER: Protocol mismatch, server 0x%x, client 0x%x",
 	      PROTOCOL_VERSION, chello.protover);
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_BADPROTO, cbuf);
+      clog("NET: %s", cbuf);
       return FALSE;
     }
 
   if (chello.cmnrev != COMMONSTAMP)
     {
-      sprintf(cbuf, "HELLO: SVR: CMB mismatch, expect %d, got %d",
+      sprintf(cbuf, "SERVER: commonblock mismatch, expected %d, got %d",
 	      COMMONSTAMP, chello.cmnrev);
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_BADCMN, cbuf);
+      clog("NET: %s", cbuf);
+      return FALSE;
     }
 
   if (chello.updates >= 1 && chello.updates <= 10)
     Context.updsec = chello.updates;
 
-  /* now send the server stats */
-  if (!sendServerStat(sInfo.sock))
-    return FALSE;
+  /* send a server stat to the udp client socket.  If the client gets
+     it, it will acknowlege it in it's ACK packet, which will tell us
+     we can do udp. woohoo! */
+  if (sInfo.tryUDP)
+    sendServerStat(sInfo.usock);
 
-  /* now we want an ack.  If we get it, we're done! */
-  if ((pkttype = readPacket(PKT_FROMCLIENT, sInfo.sock, buf, PKT_MAXSIZE, 5)) < 0)
+  /* now send the server stats normally */
+  if (!sendServerStat(sInfo.sock))
     {
-      clog("HELLO: read client Ack failed");
+      clog("NET: SERVER: hello: sendServerStat failed");
       return FALSE;
     }
-  
+
+  /* now we want an ack.  If we get it, we're done! */
+  if ((pkttype = readPacket(PKT_FROMCLIENT, sockl, buf, PKT_MAXSIZE, 60)) < 0)
+    {
+      clog("NET: SERVER: hello: read client Ack failed");
+      return FALSE;
+    }
+
   if (pkttype != CP_ACK)
-    return FALSE;
+    {
+      clog("NET: SERVER: hello: got packet type %d, expected CP_ACK", 
+           pkttype);
+      return FALSE;
+    }
+
+  if (sInfo.tryUDP)
+    {
+      /* see if the client could read our udp */
+      cpack = (cpAck_t *)buf;
+      if (cpack->code == PERR_DOUDP)
+        {
+          sInfo.doUDP = TRUE;
+          clog("NET: SERVER: hello: Client acknowleged UDP from server. Doing UDP.");
+        }
+    }
 
   return TRUE;
 }
@@ -1766,10 +1937,10 @@ void catchSignals(void)
 
 void handleSignal(int sig)
 {
+  stopUpdate();
+
   if (sig)
     clog("conquestd: exiting on signal %d", sig);
-
-  stopUpdate();
   
   if (sInfo.state == SVR_STATE_PLAY)
     {
@@ -1789,7 +1960,7 @@ void handleSignal(int sig)
       else
         {
           /* so we can detect cowards */
-          killship( Context.snum, KB_LIGHTNING );
+          clbKillShip( Context.snum, KB_LIGHTNING );
           /* turn ship off */
           Ships[Context.snum].status = SS_OFF;
         }
@@ -1818,7 +1989,7 @@ void conqend(void)
     {				/* let everyone know we're leaving */
       sprintf(msgbuf, "%s has left the game.",
 	      Users[Context.unum].alias);
-      stormsg(MSG_COMP, MSG_ALL, msgbuf);
+      clbStoreMsg(MSG_COMP, MSG_ALL, msgbuf);
     }
   
   recordCloseOutput();
