@@ -1,9 +1,9 @@
 /* 
  * Driver structure
  *
- * $Id: driver.h,v 1.2 1999/02/06 22:19:16 jon Exp $
+ * $Id: driver.h,v 1.3 2003/11/02 20:53:00 jon Exp $
  *
- * Copyright 1999 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
+ * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
 
 #ifndef DRIVER_H_INCLUDED
@@ -17,7 +17,7 @@ typedef struct {
   int drivcnt;			/* number of driver timeouts (modp1 1000) */
   int drivsecs;			/* phase of the universe in seconds */
 				/*  (modp1 five minutes) */
-  char drivowner[SIZEUSERNAME]; /* username of the driver's owner */
+  char drivowner[MAXUSERNAME]; /* username of the driver's owner */
   				/* The following are seconds since midnight. */
   int drivtime;			/* last time the driver looped */
   int playtime;			/* last time a player looped */
