@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * $Id: global.h,v 1.11 2003/11/02 20:53:00 jon Exp $
+ * $Id: global.h,v 1.13 2004/11/14 08:26:40 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -14,6 +14,7 @@
 /**********************************************************************/
 
 #include "defs.h"
+#include "cprintf.h"
 
 #ifndef GLOBAL_H
 #define GLOBAL_H
@@ -26,7 +27,6 @@
 
 CEXTERN	   int PollInputfd;	/* a copy of stdin's fd for poll()/select() */
 CEXTERN    int ConquestGID;	/* Conquest's GID */
-CEXTERN    int ConquestUID;     /* Conquest's UID */
 CEXTERN    int RMsg_Line;
 
 				/* for the semaphores */
@@ -34,12 +34,6 @@ CEXTERN    int RMsg_Line;
 #define LOCKMSG      (0)	/* lock the message portion  */
 #define LOCKCMN      (1)	/* lock everything else  */
 
-/* cprintf align values */
-#define ALIGN_CENTER 3
-#define ALIGN_LEFT   2
-#define ALIGN_RIGHT  1
-#define ALIGN_NONE   0
-
 CEXTERN int headerflag;         /* whether to show header flag */
 
 #undef CEXTERN			/* cleanup */
