@@ -5,7 +5,7 @@
  * ibuf.c - input buffering to support Function key macros
  * Jon Trulson 3/30/96
  *
- * $Id: ibuf.c,v 1.7 2003/11/02 20:53:00 jon Exp $
+ * $Id: ibuf.c,v 1.8 2004/05/08 21:01:41 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  **********************************************************************/
@@ -150,7 +150,7 @@ unsigned int iBufGetCh(void)
 
   if (!iBufCount())
     {
-      clog("IBUF GETC EMPTY, returning 0\n");
+      /*      clog("IBUF GETC EMPTY, returning 0\n");*/
       return('\0');
     }
   getRing(&c, 1, TRUE);
@@ -160,12 +160,8 @@ unsigned int iBufGetCh(void)
   
 /* DoMacro - stuff the buffer if an fkey pressed */
 
-int DoMacro(int ch)
+int DoMacro(int fkey)
 {
-  int fkey;
-  
-  fkey = (ch - KEY_F(0)) - 1 ;
-
   if (fkey < 0 || fkey >= MAX_MACROS)
   {
 #ifdef DEBUG_MACROS
