@@ -1,7 +1,7 @@
 /* 
  * Stuff for the meta server
  *
- * $Id: meta.h,v 1.2 2003/12/07 09:35:32 jon Exp $
+ * $Id: meta.h,v 1.3 2004/11/24 01:31:12 jon Exp $
  *
  * Copyright 2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -13,15 +13,18 @@
 #include "datatypes.h"
 
 #define META_VERMAJ 0
-#define META_VERMIN 1
+#define META_VERMIN 2
 #define META_VERSION  (Unsgn16)((META_VERMAJ << 8) | META_VERMIN)
 
 #define META_MAXSERVERS   1000  /* max number of servers we will track */
-#define BUFFERSZ       (1024 * 64)
+#define BUFFERSZ          (1024 * 64)
+
+#define META_GEN_STRSIZE  256   /* generic meta str size */
 
 /* internal representation of a server record for the meta server */
 typedef struct _meta_srec {
   int valid;
+  Unsgn16 version;
   Unsgn8 numactive;
   Unsgn8 numvacant;
   Unsgn8 numrobot;
@@ -32,8 +35,14 @@ typedef struct _meta_srec {
   Unsgn8 addr[CONF_SERVER_NAME_SZ]; /* server's detected address */
   Unsgn8 altaddr[CONF_SERVER_NAME_SZ]; /* specified real address */
   Unsgn8 servername[CONF_SERVER_NAME_SZ];
-  Unsgn8 serverver[CONF_SERVER_NAME_SZ]; /* server's version */
+  Unsgn8 serverver[CONF_SERVER_NAME_SZ]; /* server's proto version */
   Unsgn8 motd[CONF_SERVER_MOTD_SZ];
+
+  /* Version 0x0002 */
+  Unsgn16 protovers;
+  Unsgn8 contact[META_GEN_STRSIZE];
+  Unsgn8 walltime[META_GEN_STRSIZE];
+
 } metaSRec_t;
 
 void pipe2ul(char *str);
