@@ -4,7 +4,7 @@
  *
  * options.c - handle view/edit options feature
  *
- * $Id: options.c,v 1.5 2003/12/07 09:35:32 jon Exp $
+ * $Id: options.c,v 1.9 2004/11/24 01:31:12 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  *
@@ -14,12 +14,16 @@
 #include "conqdef.h"
 #include "conqcom.h"
 #include "color.h"
+#include "ui.h"
 #include "conf.h"
 #include "clntauth.h"
+#include "cd2lb.h"
+#include "iolb.h"
 #include "client.h"
 #include "clientlb.h"
 
 #include "context.h"
+
 struct compile_options {
   char *name;
   char *oneliner;
@@ -54,12 +58,12 @@ static void DisplayCompileOptions(void)
 
   static struct compile_options CompileOptions[] = 
   {
-    {"HAS_SETITIMER", "can do fastupdates (2 per sec)", CTYPE_BOOL, 
-#ifdef HAS_SETITIMER
+    {"HAVE_SETITIMER", "can do fastupdates (2 per sec)", CTYPE_BOOL, 
+#ifdef HAVE_SETITIMER
      (void *)TRUE
 #else
      (void *)FALSE
-#endif /* HAS_SETITIMER */
+#endif /* HAVE_SETITIMER */
     },
 
     {"USE_COMMONMLOCK", "can lock common block in memory", CTYPE_BOOL, 
@@ -94,19 +98,12 @@ static void DisplayCompileOptions(void)
 #endif /* DO_EXPLODING_SHIPS */
     },
 
-    {"ENABLE_MACROS", "can use macro keys", CTYPE_BOOL,
-#ifdef ENABLE_MACROS
-     (void *)TRUE
-#else
-     (void *)FALSE
-#endif /* ENABLE_MACROS */
-    },
 				/* last (NULL) entry */
     {NULL, NULL, CTYPE_NULL, (void *)NULL}
   };
 
   lin = 1;
-  col = ((int)(cdcols() - strlen(header)) / 2);
+  col = ((int)(Context.maxcol - strlen(header)) / 2);
 
   cprintf(lin, col, ALIGN_NONE, "#%d#%s", NoColor, header);
   
@@ -190,7 +187,7 @@ void SysOptsMenu(void)
 				/* First clear the display. */
       cdclear();
       lin = 1;
-      col = ((int)(cdcols() - strlen(header))/ 2);
+      col = ((int)(Context.maxcol - strlen(header))/ 2);
       
       cprintf(lin, col, ALIGN_NONE, "#%d#%s", NoColor, header);
       
@@ -269,7 +266,7 @@ void UserOptsMenu(int unum)
 				/* First clear the display. */
       cdclear();
       lin = 1;
-      col = ((cdcols() / 2) - (strlen(header) / 2));
+      col = ((Context.maxcol / 2) - (strlen(header) / 2));
       
       cprintf(lin, col, ALIGN_NONE, "#%d#%s", NoColor, header);
       
@@ -284,6 +281,11 @@ void UserOptsMenu(int unum)
 	}
 
       lin++;
+      lin++;
+      cprintf(lin, col, ALIGN_NONE, "#%d#UDP:  #%d# %s#%d#", LabelColor,
+              InfoColor, (cInfo.doUDP) ? "On" : "Off",
+              NoColor);
+
       lin++;
       cprintf(lin, col, ALIGN_NONE, "#%d#Flags:#%d# %s#%d#", LabelColor,
               InfoColor, clntServerFlagsStr(sStat.flags),
@@ -303,7 +305,7 @@ void UserOptsMenu(int unum)
 				/* save and reload the config */
 	  if (ChangedSomething == TRUE)
 	    {
-	      SaveUserConfig(unum);
+	      SaveUserConfig();
 	      /* set new update rate */
 	      Context.updsec = UserConf.UpdatesPerSecond;
 	      sendCommand(CPCMD_SETRATE, Context.updsec);
@@ -316,7 +318,7 @@ void UserOptsMenu(int unum)
 	      ChangedSomething = FALSE; 
 	      ViewEditMacros(macroptr);
 	      if (ChangedSomething == TRUE)
-		SaveUserConfig(unum);
+		SaveUserConfig();
 	    }
 
 	  break;
@@ -342,7 +344,7 @@ void UserOptsMenu(int unum)
 
 static void ChangeOption(struct Conf *cdata, int lin)
 {
-#define CBUFLEN 128
+#define CBUFLEN 1024
   int j, rv;
   char buf[CBUFLEN];
 
@@ -491,7 +493,7 @@ static int ViewEditOptions(struct Conf ConfigData[], int ConfSize,
     {
       cdclrl( 1, MSG_LIN2);	/* clear screen area */
       lin = 1;
-      col = ((int)(cdcols() - strlen(header))/ 2);
+      col = ((int)(Context.maxcol - strlen(header))/ 2);
 
       cprintf(lin, col, ALIGN_NONE, "#%d#%s", NoColor, header);
       
@@ -688,7 +690,7 @@ static int ViewEditMacros(struct Conf *ConfigData)
 
       cdclrl( 1, MSG_LIN2);	/* clear screen area */
       lin = 1;
-      col = ((int)(cdcols() - strlen(headerbuf)) / 2);
+      col = ((int)(Context.maxcol - strlen(headerbuf)) / 2);
 
       cprintf(lin, col, ALIGN_NONE, "#%d#%s", NoColor, headerbuf);
       
@@ -848,7 +850,7 @@ static int ViewEditMacros(struct Conf *ConfigData)
 /* DisplayHelpScreen() - display a help (actually the conf item comment)
  *                       screen for a Configuration item.
  */
-void DisplayHelpScreen(struct Conf *confitem)
+static void DisplayHelpScreen(struct Conf *confitem)
 {
   int i, col, lin;
 
@@ -863,7 +865,7 @@ void DisplayHelpScreen(struct Conf *confitem)
   lin += 2;
 
   i = 0;
-  attrset(InfoColor);
+  uiPutColor(InfoColor);
 
   while (confitem->ConfComment[i] != NULL)
     {
@@ -875,7 +877,7 @@ void DisplayHelpScreen(struct Conf *confitem)
       i++;
     }
 
-  attrset(NoColor);
+  uiPutColor(NoColor);
   cdclrl( MSG_LIN1, 2  );
   cdputc(MTXT_DONE, MSG_LIN2);
 
