@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: rndlb.c,v 1.6 2003/11/02 20:53:00 jon Exp $
+ * $Id: rndlb.c,v 1.8 2004/11/14 08:26:40 jon Exp $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -120,22 +120,6 @@ void rndini ( int seed1, int seed2 )
 /*  SYNOPSIS */
 /*    real r, rnd */
 /*    r = rnd(0) */
-#ifdef ALT_RND
-real rnd ( void )
-{
-  
-  int idx;
-  real RET;
-  
-  rndseq ( &value1, mult1, inc1, modu1 );
-  idx = ifix ( creal(value1) / creal(modu1) * TABLESIZE ) + 1;
-  RET = creal(table[idx]) / creal(modu2);
-  rndseq ( &value2, mult2, inc2, modu2 );
-  table[idx] = value2;
-  
-  return(RET);
-}
-#else
 real rnd ( void )		/* use 48bit linear congruential */
 {
   real rc;
@@ -146,7 +130,6 @@ real rnd ( void )		/* use 48bit linear congruential */
 #endif
   return(rc);
 }
-#endif
 
 /*  rnduni - random real number in the specified range */
 /*  SYNOPSIS */
@@ -167,7 +150,7 @@ int rndint ( int ilow, int ihigh )
 {
   int rc;
 
-  rc = ifix ( rnd() * creal(ihigh-ilow+1.0) ) + ilow;
+  rc = ifix ( rnd() * rfix(ihigh-ilow+1.0) ) + ilow;
 #ifdef DEBUG_RANDOM
   clog("rndint(): rc = %d", rc);
 #endif
