@@ -4,18 +4,48 @@
  *
  * server specific stuff
  *
- * $Id: server.c,v 1.4 2003/12/13 20:52:48 jon Exp $
+ * $Id: server.c,v 1.21 2004/12/26 08:19:31 jon Exp $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
 
 #include "conqdef.h"
 #include "conqcom.h"
+#include "conqlb.h"
 #include "conf.h"
 #include "server.h"
 #include "serverpkt.h"
 #include "context.h"
 #include "record.h"
+#include "conqlb.h"
+
+#define MAXUDPERRS    (15)
+static int sudperrs = 0;        /* keep track of udp write errors */
+
+#if 0
+static string guilt="Team genocided.  Any armies you were carrying died of guilt.";
+#endif
+static string guilt="Your team was genocided.";
+
+
+/* called when a write to a UDP socket fails. If the error threshold
+   is exceeded, disable UDP to client and let them know */
+static void handleUDPErr(void)
+{
+  sudperrs++;
+
+  if (sudperrs > MAXUDPERRS)
+    {
+      sInfo.tryUDP = FALSE;
+      sInfo.doUDP = FALSE;
+      close(sInfo.usock);
+      sInfo.usock = -1;
+      clog("NET: too many UDP send errors to client, switching to TCP");
+      clbStoreMsg(MSG_COMP, Context.snum, 
+              "SERVER: too many UDP send errors. Switching to TCP");
+    }
+  return;
+}
 
 int sendClientStat(int sock, Unsgn8 flags, Unsgn8 snum, Unsgn8 team, 
 		   Unsgn16 unum, Unsgn8 esystem)
@@ -107,18 +137,32 @@ int sendShip(int sock, Unsgn8 snum)
     }
   
   if ((sshiploc = spktShipLoc(snum, FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)sshiploc) <= 0)
-      return FALSE;
-
+    {
+      if (sInfo.doUDP)
+        {
+          if (writePacket(PKT_TOCLIENT, sInfo.usock, (Unsgn8 *)sshiploc) <= 0)
+            {
+              handleUDPErr();
+              return FALSE;
+            }
+        }
+      else
+        {
+          if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)sshiploc) <= 0)
+            return FALSE;
+        }
+    }
   return TRUE;
 }
 
 /* we have the potential to send 3 packets here. */
-int sendPlanet(int sock, Unsgn8 pnum)
+int sendPlanet(int sock, Unsgn8 pnum, int force)
 {
   spPlanet_t *splan;
   spPlanetSml_t *splansml;
   spPlanetLoc_t *splanloc;
+  spPlanetLoc2_t *splanloc2;
+  spPlanetInfo_t *splaninfo;
 
 #if defined(DEBUG_SERVERSEND)
   clog("sendPlanet: pnum = %d",
@@ -147,15 +191,31 @@ int sendPlanet(int sock, Unsgn8 pnum)
     if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)splansml) <= 0)
       return FALSE;
 
+  /* SP_PLANETINFO */
+  if (Context.recmode == RECMODE_ON)
+    {
+      if ((splaninfo = spktPlanetInfo(pnum, TRUE)))
+        recordWriteEvent((Unsgn8 *)splaninfo);
+    }
+
+  if ((splaninfo = spktPlanetInfo(pnum, FALSE)))
+    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)splaninfo) <= 0)
+      return FALSE;
+
+  /* we will do loc packets for recording purposes only.  loc2 is sent
+     to clients, but not recorded (server-side), since the clients
+     compute their own planetary movement based on them. */
+
   /* SP_PLANETLOC */
   if (Context.recmode == RECMODE_ON)
     {
-      if ((splanloc = spktPlanetLoc(pnum, TRUE)))
+      if ((splanloc = spktPlanetLoc(pnum, TRUE, force)))
         recordWriteEvent((Unsgn8 *)splanloc);
     }
 
-  if ((splanloc = spktPlanetLoc(pnum, FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)splanloc) <= 0)
+  /* SP_PLANETLOC2 */
+  if ((splanloc2 = spktPlanetLoc2(pnum, FALSE, force)))
+    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)splanloc2) <= 0)
       return FALSE;
 
   return TRUE;
@@ -230,6 +290,7 @@ int sendTorp(int sock, Unsgn8 tsnum, Unsgn8 tnum)
 {
   spTorp_t *storp;
   spTorpLoc_t *storploc;
+  spTorpEvent_t *storpev;
 
   /* no point in sending torp data if we're not playing */
   if (sInfo.state != SVR_STATE_PLAY)
@@ -245,34 +306,65 @@ int sendTorp(int sock, Unsgn8 tsnum, Unsgn8 tnum)
   clog("sendTorp: %d %d", tsnum, tnum);
 #endif
 
-  /* SP_TORP */
 
+  /* SP_TORPEVENT */
+  /* we only send these */
+  if ((storpev = spktTorpEvent(tsnum, tnum, FALSE)))
+    {
+      if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)storpev) <= 0)
+        return FALSE;
+    }
+
+  /* SP_TORP */
+  /* we only record these */
   if (Context.recmode == RECMODE_ON)
     {
       if ((storp = spktTorp(tsnum, tnum, TRUE)))
         recordWriteEvent((Unsgn8 *)storp);
     }
 
-  if ((storp = spktTorp(tsnum, tnum, FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)storp) <= 0)
-      return FALSE;
-  
   /* SP_TORPLOC */
 
+  /* we only record these */
   if (Context.recmode == RECMODE_ON)
     {
       if ((storploc = spktTorpLoc(tsnum, tnum, TRUE)))
         recordWriteEvent((Unsgn8 *)storploc);
     }
 
-  if ((storploc = spktTorpLoc(tsnum, tnum, FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)storploc) <= 0)
-      return FALSE;
-  
   return TRUE;
 }
 
-int sendMessage(int sock, Msg_t *msg)
+/* send a Feedback (MSG_FLAGS_FEEDBACK) message to the client.
+ * For MSG_FLAGS_FEEDBACK msgs, we do not need to deposit into                
+ * the CB ringbuffer and deal with the associated 'lock-hogging' for a        
+ * busy server.  We will send these immediately and return.                   
+ */
+void sendFeedback(char *msg)
+{
+  char buf[MESSAGE_SIZE + 64];
+  Msg_t themsg;
+
+  memset((void *)&themsg, 0, sizeof(Msg_t));
+  themsg.msgto = Context.snum;
+  themsg.msgfrom = MSG_COMP;
+  themsg.flags = MSG_FLAGS_FEEDBACK;
+  strncpy(themsg.msgbuf, msg, MESSAGE_SIZE - 1);
+
+  sendMessage(&themsg);
+
+  if (SysConf.LogMessages == TRUE)
+    {
+      clbFmtMsg(themsg.msgto, themsg.msgfrom, buf);
+      clog("MSG:FEEDBACK: %s: %s",
+           buf, themsg.msgbuf);
+    }
+
+  return;
+}
+
+/* send a msg to the client */
+int sendMessage(Msg_t *msg)
 {
   spMessage_t smsg;
 
@@ -299,11 +391,10 @@ int sendMessage(int sock, Msg_t *msg)
 
   /* don't record feeback or tersable msgs */
   if (Context.recmode == RECMODE_ON)
-    if (!(smsg.flags & MSG_FLAGS_FEEDBACK) && 
-        !(smsg.flags & MSG_FLAGS_TERSABLE))
+    if (!(smsg.flags & (MSG_FLAGS_FEEDBACK | MSG_FLAGS_TERSABLE)))
       recordWriteEvent((Unsgn8 *)&smsg);
 
-  if (!writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)&smsg))
+  if (!writePacket(PKT_TOCLIENT, sInfo.sock, (Unsgn8 *)&smsg))
     {
       clog("sendMessage: writePacket failed\n");
       return FALSE;
@@ -315,19 +406,6 @@ int sendMessage(int sock, Msg_t *msg)
 int sendTeam(int sock, Unsgn8 team, int force)
 {
   spTeam_t *steam;
-  static time_t oldtime[NUMALLTEAMS] = {0}; /* keep track of the time */
-  time_t now = getnow(NULL, 0);	/* for each team */
-
-  /* we want to just send these every TEAM_UPDATE_INTERVAL seconds
-     since they can change often (everytime someone fires a torp
-     for example). If the force flag is set, we reset everything so
-     new packets will be delivered. */
-
-  if ((abs((unsigned int)now - (unsigned int)oldtime[team]) < 
-       TEAM_UPDATE_INTERVAL) && !force)
-    return TRUE;
-  else
-    oldtime[team] = now;
 
 #if defined(DEBUG_SERVERSEND)
   clog("sendTeam: team = %d, f = %d", team, force);
@@ -349,16 +427,6 @@ int sendTeam(int sock, Unsgn8 team, int force)
 int sendConqInfo(int sock, int force)
 {
   spConqInfo_t *spci;
-  static time_t oldtime = 0; /* keep track of the time */
-  time_t now = getnow(NULL, 0);	
-
-  /* we want to just send these every CONQINFO_UPDATE_INTERVAL seconds */
-
-  if ((abs((unsigned int)now - (unsigned int)oldtime) < 
-       CONQINFO_UPDATE_INTERVAL) && !force)
-    return TRUE;
-  else
-    oldtime = now;
 
 #if defined(DEBUG_SERVERSEND)
   clog("sendConqInfo: f = %d", force);
@@ -374,20 +442,10 @@ int sendConqInfo(int sock, int force)
 int sendHistory(int sock, int hnum)
 {
   spHistory_t *shist;
-  static time_t oldtime[MAXHISTLOG] = {0}; /* keep track of the time */
-  time_t now = getnow(NULL, 0);	
-
-  /* we want to just send these every HISTORY_UPDATE_INTERVAL seconds */
 
   if (hnum < 0 || hnum > MAXHISTLOG)
     return FALSE;
 
-  if ((abs((unsigned int)now - (unsigned int)oldtime[hnum]) < 
-       HISTORY_UPDATE_INTERVAL))
-    return TRUE;
-  else
-    oldtime[hnum] = now;
-
 #if defined(DEBUG_SERVERSEND)
   clog("sendHistory: hnum = %d", hnum);
 #endif
@@ -399,6 +457,27 @@ int sendHistory(int sock, int hnum)
   return TRUE;
 }
 
+int sendDoomsday(int sock)
+{
+  spDoomsday_t *dd;
+
+#if defined(DEBUG_SERVERSEND)
+  clog("sendDoomsday");
+#endif
+
+  if (Context.recmode == RECMODE_ON)
+    {
+      if ((dd = spktDoomsday(TRUE)))
+        recordWriteEvent((Unsgn8 *)dd);
+    }
+
+  if ((dd = spktDoomsday(FALSE)))
+    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)dd) <= 0)
+      return FALSE;
+
+  return TRUE;
+}
+  
 
 void procSetName(Unsgn8 *buf)
 {
@@ -481,17 +560,13 @@ void procSetWarp(cpCommand_t *swarp)
       /* See if engines are working. */
       if ( Ships[snum].efuse > 0 )
 	{
-	  stormsgf(MSG_COMP, snum, 
-                   "Engines are currently overloaded.", 
-                   MSG_FLAGS_FEEDBACK);
+	  sendFeedback("Engines are currently overloaded.");
 	  return;
 	}
             /* No charge if already warp 0. */
-      if ( usefuel( snum, ENGINES_ON_FUEL, FALSE, TRUE ) == FALSE)
+      if ( clbUseFuel( snum, ENGINES_ON_FUEL, FALSE, TRUE ) == FALSE)
 	{
-	  stormsgf(MSG_COMP, snum, 
-                   "We don't have enough fuel.", 
-                   MSG_FLAGS_FEEDBACK);
+	  sendFeedback("We don't have enough fuel.");
 	  return;
 	}
       
@@ -516,7 +591,7 @@ void procSetWarp(cpCommand_t *swarp)
     {
       sprintf(cbuf, 
               "(Due to damage, warp is currently limited to %.1f.)", mw);
-      stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK);
+      sendFeedback(cbuf);
     }
 
   return;
@@ -604,21 +679,19 @@ void procCloak(cpCommand_t *cmd)
     }
   if ( Ships[snum].efuse > 0 )
     {
-      stormsgf(MSG_COMP, snum, 
-               "Engines are currently overloaded.", 
-               MSG_FLAGS_FEEDBACK);
+      sendFeedback("Engines are currently overloaded.");
       return;
     }
   if ( Ships[snum].fuel < CLOAK_ON_FUEL )
     {
-      stormsgf(MSG_COMP, snum, nofuel, MSG_FLAGS_FEEDBACK);
+      sendFeedback(nofuel);
       return;
     }
 
   SFCLR(snum, SHIP_F_REPAIR);
-  if ( ! usefuel( snum, CLOAK_ON_FUEL, FALSE, TRUE ) )
+  if ( ! clbUseFuel( snum, CLOAK_ON_FUEL, FALSE, TRUE ) )
     {
-      stormsgf(MSG_COMP, snum, nofuel, MSG_FLAGS_FEEDBACK);
+      sendFeedback(nofuel);
       return;
     }
 
@@ -644,7 +717,7 @@ void procDetSelf(cpCommand_t *cmd)
 #endif
 
   for ( j = 0; j < MAXTORPS; j++ )
-    detonate( snum, j );
+    clbDetonate( snum, j );
 
   return;
 }
@@ -663,7 +736,7 @@ void procDetEnemy(cpCommand_t *cmd)
   clog("PROC DETENEMY");
 #endif
 
-  enemydet( snum );
+  clbEnemyDet( snum );
 
   return;
 }
@@ -682,7 +755,7 @@ void procDistress(cpCommand_t *cmd)
   if (cmd->cmd != CPCMD_DISTRESS)
     return;
 
-  tofriendly = (int)htons(cmd->detail);
+  tofriendly = (int)ntohs(cmd->detail);
 
 #if defined(DEBUG_SERVERPROC)
   clog("PROC DISTRESS: tofriendly = %d", tofriendly);
@@ -754,9 +827,9 @@ void procDistress(cpCommand_t *cmd)
     }
   
   if (tofriendly)
-    stormsg( snum, MSG_FRIENDLY, cbuf );
+    clbStoreMsg( snum, MSG_FRIENDLY, cbuf );
   else
-    stormsg( snum, -Ships[snum].team, cbuf );
+    clbStoreMsg( snum, -Ships[snum].team, cbuf );
   
   return;
   
@@ -787,30 +860,24 @@ void procFirePhaser(cpCommand_t *cmd)
 
   if ( SCLOAKED(snum) )
     {
-      stormsgf(MSG_COMP, snum, 
-               "The cloaking device is using all available power.",
-               MSG_FLAGS_FEEDBACK);
+      sendFeedback("The cloaking device is using all available power.");
       return;
     }
 
   if ( Ships[snum].wfuse > 0 )
     {
-      stormsgf(MSG_COMP, snum, 
-               "Weapons are currently overloaded.", 
-               MSG_FLAGS_FEEDBACK);
+      sendFeedback("Weapons are currently overloaded.");
       return;
     }
 
   if ( Ships[snum].fuel < PHASER_FUEL )
     {
-      stormsgf(MSG_COMP, snum, 
-               "Not enough fuel to fire phasers.", 
-               MSG_FLAGS_FEEDBACK);
+      sendFeedback("Not enough fuel to fire phasers.");
       return;
     }
   
-  if ( !phaser( snum, dir ) )
-    stormsgf(MSG_COMP, snum, ">PHASERS DRAINED<", MSG_FLAGS_FEEDBACK);
+  if ( !clbPhaser( snum, dir ) )
+    sendFeedback(">PHASERS DRAINED<");
 
   return;
 }
@@ -833,13 +900,13 @@ void procOrbit(cpCommand_t *cmd)
   if ( ( Ships[snum].warp == ORBIT_CW ) || ( Ships[snum].warp == ORBIT_CCW ) )
     return;
 
-  if ( ! findorbit( snum, &pnum ) )
+  if ( ! clbFindOrbit( snum, &pnum ) )
     return;
 
   if ( Ships[snum].warp > MAX_ORBIT_WARP )
     return;
 
-  orbit( snum, pnum );
+  clbOrbit( snum, pnum );
   
   return;
 }
@@ -874,6 +941,7 @@ void procCoup(cpCommand_t *cmd)
   real failprob;
   string nhp="We must be orbiting our home planet to attempt a coup.";
   char cbuf[128];
+  int rv = -1;
 
   if (!validPkt(CP_COMMAND, cmd))
     return;
@@ -888,37 +956,32 @@ void procCoup(cpCommand_t *cmd)
   /* Check for allowability. */
   if ( oneplace( Ships[snum].kills ) < MIN_COUP_KILLS )
     {
-      stormsgf(MSG_COMP, snum,
-	      "Fleet orders require three kills before a coup can be attempted.",
-	       MSG_FLAGS_FEEDBACK);
+      sendFeedback("Fleet orders require three kills before a coup can be attempted.");
       return;
     }
   for ( i = 1; i <= NUMPLANETS; i = i + 1 )
-    if ( Planets[i].team == Ships[snum].team && Planets[i].armies > 0 )
+    if ( Planets[i].real && (Planets[i].team == Ships[snum].team) && 
+         (Planets[i].armies > 0) )
       {
-	 stormsgf(MSG_COMP, snum,
-		 "We don't need to coup, we still have armies left!",
-		  MSG_FLAGS_FEEDBACK);
+	 sendFeedback("We don't need to coup, we still have armies left!");
 	return;
       }
 
   if ( Ships[snum].warp >= 0.0 )
     {
-      stormsgf(MSG_COMP, snum, nhp, MSG_FLAGS_FEEDBACK );
+      sendFeedback(nhp);
       return;
     }
 
   pnum = -Ships[snum].lock;
   if ( pnum != Teams[Ships[snum].team].homeplanet )
     {
-      stormsgf(MSG_COMP, snum, nhp, MSG_FLAGS_FEEDBACK );
+      sendFeedback(nhp);
       return;
     }
   if ( Planets[pnum].armies > MAX_COUP_ENEMY_ARMIES )
     {
-      stormsgf(MSG_COMP, snum, 
-	      "The enemy is still too strong to attempt a coup.",
-	       MSG_FLAGS_FEEDBACK);
+      sendFeedback("The enemy is still too strong to attempt a coup.");
       return;
     }
   i = Planets[pnum].uninhabtime;
@@ -926,7 +989,7 @@ void procCoup(cpCommand_t *cmd)
     {
       sprintf( cbuf, "This planet is uninhabitable for %d more minutes.",
 	     i );
-      stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK);
+      sendFeedback(cbuf);
       return;
     }
   
@@ -937,17 +1000,17 @@ void procCoup(cpCommand_t *cmd)
   if ( i > 0 )
     {
       sprintf( cbuf, "Our forces need %d more minutes to organize.", i );
-      stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK);
+      sendFeedback(cbuf);
       return;
     }
   
   /* Now wait it out... */
-  stormsgf( MSG_COMP, snum, "Attempting coup...", MSG_FLAGS_FEEDBACK );
+  sendFeedback("Attempting coup...");
   grand( &entertime );
   while ( dgrand( entertime, &now ) < COUP_GRAND )
     {
       /* See if we're still alive. */
-      if ( ! stillalive( Context.snum ) )
+      if ( ! clbStillAlive( Context.snum ) )
 	return;
       
       /* Sleep */
@@ -958,9 +1021,7 @@ void procCoup(cpCommand_t *cmd)
   if ( Planets[pnum].team == Ships[snum].team )
     {
       PVUNLOCK(&ConqInfo->lockword);
-      stormsgf( MSG_COMP, snum, 
-	       "Sensors show hostile forces eliminated from the planet.",
-		MSG_FLAGS_FEEDBACK);
+      sendFeedback("Sensors show hostile forces eliminated from the planet.");
       return;
     }
   
@@ -971,16 +1032,28 @@ void procCoup(cpCommand_t *cmd)
       /* Failed; setup new reorganization time. */
       Teams[Ships[snum].team].couptime = rndint( 5, 10 );
       PVUNLOCK(&ConqInfo->lockword);
-      stormsgf( MSG_COMP, snum, "Coup unsuccessful.", MSG_FLAGS_FEEDBACK );
+      sendFeedback("Coup unsuccessful.");
       return;
     }
   
-  takeplanet( pnum, snum );
+  rv = clbTakePlanet( pnum, snum );
+
+  /* Make the planet not scanned. */
+  for ( i = 0; i < NUMPLAYERTEAMS; i = i + 1 )
+    Planets[pnum].scanned[i] = FALSE;
+
+  /* ...except by us */
+  Planets[pnum].scanned[Ships[snum].team] = TRUE;
+  
   Planets[pnum].armies = rndint( 10, 20 );	/* create token coup force */
   Users[Ships[snum].unum].stats[USTAT_COUPS] += 1;
   Teams[Ships[snum].team].stats[TSTAT_COUPS] += 1;
   PVUNLOCK(&ConqInfo->lockword);
-  stormsgf( MSG_COMP, snum, "Coup successful!", MSG_FLAGS_FEEDBACK );
+
+  sendFeedback("Coup successful!");
+
+  if (rv >= 0 && rv < NUMPLAYERTEAMS)  /* someone was geno'd, send team msg */
+    clbStoreMsg( MSG_COMP, -rv, guilt );
 
   /* force a team update for this ship */
   sendTeam(sInfo.sock, Ships[snum].team, TRUE);
@@ -1013,31 +1086,25 @@ void procFireTorps(Unsgn8 *buf)
 
   if ( SCLOAKED(snum) )
     {
-      stormsgf(MSG_COMP, snum, 
-               "The cloaking device is using all available power.",
-	       MSG_FLAGS_FEEDBACK);
+      sendFeedback("The cloaking device is using all available power.");
       return;
     }
 
   if ( Ships[snum].wfuse > 0 )
     {
-      stormsgf(MSG_COMP, snum, 
-               "Weapons are currently overloaded.", 
-               MSG_FLAGS_FEEDBACK);
+      sendFeedback("Weapons are currently overloaded.");
       return;
     }
 
   if ( Ships[snum].fuel < TORPEDO_FUEL )
     {
-      stormsgf(MSG_COMP, snum, 
-               "Not enough fuel to launch a torpedo.", 
-               MSG_FLAGS_FEEDBACK);
+      sendFeedback("Not enough fuel to launch a torpedo.");
       return;
     }
 
-  if ( ! launch( snum, dir, num, LAUNCH_NORMAL ) )
+  if ( ! clbLaunch( snum, dir, num, LAUNCH_NORMAL ) )
     {
-      stormsgf(MSG_COMP, snum, ">TUBES EMPTY<", MSG_FLAGS_FEEDBACK);
+      sendFeedback(">TUBES EMPTY<");
     }
   
   return;
@@ -1063,7 +1130,7 @@ void procMessage(Unsgn8 *buf)
   clog("PROC MESSAGE: to %d", to);
 #endif
 
-  stormsg(snum, to, cmsg->msg);
+  clbStoreMsg(snum, to, cmsg->msg);
   checkOperExec(snum, to, cmsg->msg);
 
   return;
@@ -1143,7 +1210,7 @@ void procSetWar(cpCommand_t *cmd)
       while ( dgrand( entertime, &now ) < REARM_GRAND )
 	{
 	  /* See if we're still alive. */
-	  if ( ! stillalive( Context.snum ) )
+	  if ( ! clbStillAlive( Context.snum ) )
 	    return;
 	  
 	  /* Sleep */
@@ -1179,9 +1246,7 @@ void procRefit(cpCommand_t *cmd)
   /* Check for allowability. */
   if ( oneplace( Ships[snum].kills ) < MIN_REFIT_KILLS )
     {
-      stormsgf(MSG_COMP, snum, 
-               "You must have at least one kill to refit.",
-               MSG_FLAGS_FEEDBACK);
+      sendFeedback("You must have at least one kill to refit.");
       return;
     }
 
@@ -1189,17 +1254,13 @@ void procRefit(cpCommand_t *cmd)
 
   if (Planets[pnum].team != Ships[snum].team || Ships[snum].warp >= 0.0)
     {
-      stormsgf(MSG_COMP, snum, 
-               "We must be orbiting a team owned planet to refit.",
-               MSG_FLAGS_FEEDBACK);
+      sendFeedback("We must be orbiting a team owned planet to refit.");
       return;
     }
 
   if (Ships[snum].armies != 0)
     {
-      stormsgf(MSG_COMP, snum, 
-               "You cannot refit while carrying armies",
-               MSG_FLAGS_FEEDBACK);
+      sendFeedback("You cannot refit while carrying armies");
       return;
     }
   
@@ -1208,7 +1269,7 @@ void procRefit(cpCommand_t *cmd)
   while ( dgrand( entertime, &now ) < REFIT_GRAND )
     {
       /* See if we're still alive. */
-      if ( ! stillalive( snum ) )
+      if ( ! clbStillAlive( snum ) )
 	return;
       
       /* Sleep */
@@ -1269,9 +1330,9 @@ void procTow(cpCommand_t *cmd)
   if ( Ships[snum].towedby != 0 )
     {
       c_strcpy( "But we are being towed by ", cbuf );
-      appship( Ships[snum].towing, cbuf );
+      appship( Ships[snum].towedby, cbuf );
       appchr( '!', cbuf );
-      stormsgf( MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK );
+      sendFeedback(cbuf);
       return;
     }
   if ( Ships[snum].towing != 0 )
@@ -1279,7 +1340,7 @@ void procTow(cpCommand_t *cmd)
       c_strcpy( "But we're already towing ", cbuf );
       appship( Ships[snum].towing, cbuf );
       appchr( '.', cbuf );
-      stormsgf( MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK );
+      sendFeedback(cbuf);
       return;
     }
   cbuf[0] = 0;
@@ -1311,7 +1372,7 @@ void procTow(cpCommand_t *cmd)
     }
   PVUNLOCK(&ConqInfo->lockword);
 
-  stormsgf( MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK );
+  sendFeedback(cbuf);
   
   return;
 
@@ -1344,7 +1405,7 @@ void procUnTow(cpCommand_t *cmd)
 	  grand( &entertime );
 	  while ( dgrand( entertime, &now ) < BREAKAWAY_GRAND )
 	    {
-	      if ( ! stillalive( Context.snum ) )
+	      if ( ! clbStillAlive( Context.snum ) )
 		return;
 	      
 	      c_sleep( ITER_SECONDS );
@@ -1352,8 +1413,7 @@ void procUnTow(cpCommand_t *cmd)
 	    }
 	}
       if ( warsome && ( rnd() > BREAKAWAY_PROB ) )
-	stormsgf(MSG_COMP, snum, "Attempt to break free failed.",
-                 MSG_FLAGS_FEEDBACK);
+	sendFeedback("Attempt to break free failed.");
       else
 	{
 	  c_strcpy( "Breaking free from ship ", cbuf );
@@ -1363,7 +1423,16 @@ void procUnTow(cpCommand_t *cmd)
 	    {
 	      /* Coast to a stop. */
 	      Ships[snum].head = Ships[Ships[snum].towedby].head;
-	      Ships[snum].warp = Ships[Ships[snum].towedby].warp;
+              
+              if (!SysConf.AllowSlingShot)
+                {               /* only set warp if valid JET - 9/15/97 */
+                  if (Ships[Ships[snum].towedby].warp >= 0.0)
+                    Ships[snum].warp = Ships[Ships[snum].towedby].warp;
+                  else
+                    Ships[snum].warp = 2.0;
+                }
+              else
+                Ships[snum].warp = Ships[Ships[snum].towedby].warp;
 	      
 	      /* Release the tow. */
 	      if ( Ships[Ships[snum].towedby].towing != 0 )
@@ -1372,7 +1441,7 @@ void procUnTow(cpCommand_t *cmd)
 	    }
 	  PVUNLOCK(&ConqInfo->lockword);
 	  appchr( '.', cbuf );
-	  stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK);
+	  sendFeedback(cbuf);
 	}
     }
   else if ( Ships[snum].towing != 0 )
@@ -1391,7 +1460,7 @@ void procUnTow(cpCommand_t *cmd)
               if (Ships[snum].warp >= 0.0)
                 Ships[Ships[snum].towing].warp = Ships[snum].warp;
               else
-                Ships[Ships[snum].towing].warp = 2;
+                Ships[Ships[snum].towing].warp = 2.0;
             }
           else
             Ships[Ships[snum].towing].warp = Ships[snum].warp;
@@ -1403,11 +1472,10 @@ void procUnTow(cpCommand_t *cmd)
 	}
       PVUNLOCK(&ConqInfo->lockword);
       appchr( '.', cbuf );
-      stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK);
+      sendFeedback(cbuf);
     }
   else
-    stormsgf(MSG_COMP, snum, "No tractor beam activity detected.",
-            MSG_FLAGS_FEEDBACK);
+    sendFeedback("No tractor beam activity detected.");
   
   return;
   
@@ -1445,33 +1513,29 @@ void procBomb(cpCommand_t *cmd)
   /* Check for allowability. */
   if ( Ships[snum].warp >= 0.0 )
     {
-      stormsgf(MSG_COMP, snum, "We must be orbiting a planet to bombard it.",
-	       MSG_FLAGS_FEEDBACK );
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      sendFeedback("We must be orbiting a planet to bombard it.");
       return;
     }
   pnum = -Ships[snum].lock;
   if ( Planets[pnum].type == PLANET_SUN || Planets[pnum].type == PLANET_MOON ||
       Planets[pnum].team == TEAM_NOTEAM || Planets[pnum].armies == 0 )
     {
-      stormsgf(MSG_COMP, snum, "There is no one there to bombard.",
-	       MSG_FLAGS_FEEDBACK);
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      sendFeedback("There is no one there to bombard.");
       return;
     }
   if ( Planets[pnum].team == Ships[snum].team )
     {
-      stormsgf(MSG_COMP, snum, "We can't bomb our own armies!",
-	      MSG_FLAGS_FEEDBACK);
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      sendFeedback("We can't bomb our own armies!");
       return;
     }
   if ( Planets[pnum].team != TEAM_SELFRULED && Planets[pnum].team != TEAM_GOD )
     if ( ! Ships[snum].war[Planets[pnum].team] )
       {
-	stormsgf(MSG_COMP, snum, "But we are not at war with this planet!",
-		 MSG_FLAGS_FEEDBACK);
 	sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	sendFeedback("But we are not at war with this planet!");
 	return;
       }
   
@@ -1481,15 +1545,15 @@ void procBomb(cpCommand_t *cmd)
     {
       /* For a team planet make the war sticky and send an intruder alert. */
       Ships[snum].rwar[Planets[pnum].team] = TRUE;
-      intrude( snum, pnum );
+      clbIntrude( snum, pnum );
     }
   /* Planets owned by GOD have a special defense system. */
   if ( Planets[pnum].team == TEAM_GOD )
     {
       sprintf( cbuf, "That was a bad idea, %s...", Ships[snum].alias );
-      stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK);
-      damage( snum,  rnduni( 50.0, 100.0 ), KB_LIGHTNING );
+      clbDamage( snum,  rnduni( 50.0, 100.0 ), KB_LIGHTNING );
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      sendFeedback(cbuf);
       return;
     }
   
@@ -1504,7 +1568,7 @@ void procBomb(cpCommand_t *cmd)
   grand( &entertime );		/* get start time */
   while(TRUE)
     {
-      if ( ! stillalive( Context.snum ) )
+      if ( ! clbStillAlive( Context.snum ) )
 	return;
       if ( isPacketWaiting(sInfo.sock) )
 	break;
@@ -1514,19 +1578,17 @@ void procBomb(cpCommand_t *cmd)
 	{
 	  if ( Ships[snum].wfuse > 0 )
 	    {
-	      stormsgf(MSG_COMP, snum, "Weapons are currently overloaded.",
-		       MSG_FLAGS_FEEDBACK);
 	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
 		      NULL);
+	      sendFeedback("Weapons are currently overloaded.");
 	      goto cbrk22; /* break 2;*/
 	    }
 	  x = BOMBARD_FUEL * (real)(BOMBARD_GRAND / 1000.0);
-	  if ( ! usefuel( snum, x, TRUE, TRUE ) )
+	  if ( ! clbUseFuel( snum, x, TRUE, TRUE ) )
 	    {
-	      stormsgf(MSG_COMP, snum, "Not enough fuel to bombard.",
-		       MSG_FLAGS_FEEDBACK);
 	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
 		      NULL);
+	      sendFeedback("Not enough fuel to bombard.");
 	      goto cbrk22; /* break 2;*/
 	    }
 	  /*  entertime = mod( entertime + BOMBARD_GRAND, 24*60*60*1000 );*/
@@ -1542,9 +1604,9 @@ void procBomb(cpCommand_t *cmd)
 		{
 		  /* No more armies left to bomb. */
 		  PVUNLOCK(&ConqInfo->lockword);
-		  stormsgf(MSG_COMP, snum, lastfew, MSG_FLAGS_FEEDBACK);
 		  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
 			  NULL);
+		  sendFeedback(lastfew);
 		  goto cbrk22; /* break 2;*/
 		}
 	      Planets[pnum].armies = Planets[pnum].armies - 1;
@@ -1560,8 +1622,8 @@ void procBomb(cpCommand_t *cmd)
       if ( Planets[pnum].armies <= MIN_BOMB_ARMIES )
 	{
 	  /* No more armies left to bomb. */
-	  stormsgf(MSG_COMP, snum, lastfew, MSG_FLAGS_FEEDBACK);
 	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	  sendFeedback(lastfew);
 	  break;
 	}
       
@@ -1575,7 +1637,7 @@ void procBomb(cpCommand_t *cmd)
 	    c_strcpy( "ies", buf );
 	  sprintf( cbuf, "Bombing %s, %d arm%s killed, %d left.",
 		 Planets[pnum].name, total, buf, oparmies );
-	  stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK);
+	  sendFeedback(cbuf);
 	  
 	  ototal = total;
 	}
@@ -1605,6 +1667,7 @@ void procBeam(cpCommand_t *cmd)
   char cbuf[BUFFER_SIZE];
   real rkills;
   string lastfew="Fleet orders prohibit removing the last three armies.";
+  int rv = -1;
 
   if (!validPkt(CP_COMMAND, cmd))
     return;
@@ -1634,10 +1697,8 @@ void procBeam(cpCommand_t *cmd)
   /* Check for allowability. */
   if ( Ships[snum].warp >= 0.0 )
     {
-      stormsgf(MSG_COMP, snum, 
-	       "We must be orbiting a planet to use the transporter.",
-	       MSG_FLAGS_FEEDBACK);
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      sendFeedback("We must be orbiting a planet to use the transporter.");
       return;
     }
   pnum = -Ships[snum].lock;
@@ -1645,26 +1706,20 @@ void procBeam(cpCommand_t *cmd)
     {
       if ( Planets[pnum].type == PLANET_SUN )
 	{
-	  stormsgf(MSG_COMP, snum,
-		   "Idiot!  Our armies will fry down there!", 
-		   MSG_FLAGS_FEEDBACK );
 	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	  sendFeedback("Idiot!  Our armies will fry down there!");
 	  return;
 	}
       else if ( Planets[pnum].type == PLANET_MOON )
 	{
-	  stormsgf(MSG_COMP, snum, 
-		   "Fool!  Our armies will suffocate down there!",
-		   MSG_FLAGS_FEEDBACK );
 	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	  sendFeedback("Fool!  Our armies will suffocate down there!");
 	  return;
 	}
       else if ( Planets[pnum].team == TEAM_GOD )
 	{
-	  stormsgf(MSG_COMP, snum,
-		   "GOD->you: YOUR ARMIES AREN'T GOOD ENOUGH FOR THIS PLANET.",
-		   MSG_FLAGS_FEEDBACK );
 	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	  sendFeedback("GOD->you: YOUR ARMIES AREN'T GOOD ENOUGH FOR THIS PLANET.");
 	  return;
 	}
     }
@@ -1677,8 +1732,8 @@ void procBeam(cpCommand_t *cmd)
       if ( i != 1 )
 	appchr( 's', cbuf );
       appchr( '.', cbuf );
-      stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK );
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      sendFeedback(cbuf);
       return;
     }
   
@@ -1687,17 +1742,16 @@ void procBeam(cpCommand_t *cmd)
       Planets[pnum].team != TEAM_NOTEAM )
     if ( ! Ships[snum].war[Planets[pnum].team] && Planets[pnum].armies != 0) /* can take empty planets */
       {
-	stormsgf(MSG_COMP, snum, "But we are not at war with this planet!", 
-		 MSG_FLAGS_FEEDBACK );
 	sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	sendFeedback("But we are not at war with this planet!");
 	return;
       }
   
   if ( Ships[snum].armies == 0 &&
       Planets[pnum].team == Ships[snum].team && Planets[pnum].armies <= MIN_BEAM_ARMIES )
     {
-      stormsgf(MSG_COMP, snum, lastfew, MSG_FLAGS_FEEDBACK );
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      sendFeedback(lastfew);
       return;
     }
   
@@ -1705,16 +1759,14 @@ void procBeam(cpCommand_t *cmd)
 
   if ( rkills < (real)1.0 )
     {
-      stormsgf(MSG_COMP, snum, 
-	       "Fleet orders prohibit beaming armies until you have a kill.",
-	       MSG_FLAGS_FEEDBACK );
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      sendFeedback("Fleet orders prohibit beaming armies until you have a kill.");
       return;
     }
   
   /* Figure out what can be beamed. */
   downmax = Ships[snum].armies;
-  if ( spwar(snum,pnum) ||
+  if ( clbSPWar(snum,pnum) ||
       Planets[pnum].team == TEAM_SELFRULED ||
       Planets[pnum].team == TEAM_NOTEAM ||
       Planets[pnum].team == TEAM_GOD ||
@@ -1740,8 +1792,8 @@ void procBeam(cpCommand_t *cmd)
 	  else
 	    appstr( "ies are", cbuf );
 	  appstr( " reluctant to beam aboard a pirate vessel.", cbuf );
-	  stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK );
 	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	  sendFeedback(cbuf);
 	  return;
 	}
       upmax = 0;
@@ -1750,8 +1802,8 @@ void procBeam(cpCommand_t *cmd)
   /* Figure out which direction to beam. */
   if ( upmax <= 0 && downmax <= 0 )
     {
-      stormsgf(MSG_COMP, snum, "There is no one to beam.", MSG_FLAGS_FEEDBACK );
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      sendFeedback("There is no one to beam.");
       return;
     }
   if ( upmax <= 0 )
@@ -1783,7 +1835,7 @@ void procBeam(cpCommand_t *cmd)
       Ships[snum].rwar[Planets[pnum].team] = TRUE;
       
       /* Chance to create a robot here. */
-      intrude( snum, pnum );
+      clbIntrude( snum, pnum );
     }
   
   /* Lower shields. */
@@ -1799,7 +1851,7 @@ void procBeam(cpCommand_t *cmd)
   grand( &entertime );
   while(TRUE)
     {
-      if ( ! stillalive( Context.snum ) )
+      if ( ! clbStillAlive( Context.snum ) )
 	return;
       if ( isPacketWaiting(sInfo.sock) )
 	break;
@@ -1815,9 +1867,9 @@ void procBeam(cpCommand_t *cmd)
 	      if ( Planets[pnum].armies <= MIN_BEAM_ARMIES )
 		{
 		  PVUNLOCK(&ConqInfo->lockword);
-		  stormsgf(MSG_COMP, snum, lastfew, MSG_FLAGS_FEEDBACK );
 		  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
 			  NULL);
+		  sendFeedback(lastfew);
 		  break;
 		}
 	      Ships[snum].armies = Ships[snum].armies + 1;
@@ -1829,7 +1881,7 @@ void procBeam(cpCommand_t *cmd)
 	      Ships[snum].armies = Ships[snum].armies - 1;
 	      if ( Planets[pnum].team == TEAM_NOTEAM || Planets[pnum].armies == 0 )
 		{
-		  takeplanet( pnum, snum );
+		  rv = clbTakePlanet( pnum, snum );
 		  conqed = TRUE;
 		}
 	      else if ( Planets[pnum].team != Ships[snum].team )
@@ -1837,7 +1889,7 @@ void procBeam(cpCommand_t *cmd)
 		  Planets[pnum].armies = Planets[pnum].armies - 1;
 		  if ( Planets[pnum].armies == 0 )
 		    {
-		      zeroplanet( pnum, snum );
+		      rv = clbZeroPlanet( pnum, snum );
 		      zeroed = TRUE;
 		    }
 		}
@@ -1846,12 +1898,17 @@ void procBeam(cpCommand_t *cmd)
 	    }
 	  PVUNLOCK(&ConqInfo->lockword);
 	  total = total + 1;
-	  
+
+	  /* someone was geno'd, send team msg */
+          if (rv >= 0 && rv < NUMPLAYERTEAMS)  
+            clbStoreMsg( MSG_COMP, -rv, guilt );
+
 	  if ( total >= num )
 	    {
 	      /* Done. */
 	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_DONE, 
 		      NULL);
+              sendFeedback("");
 	      goto cbrk21; 
 	    }
 	}
@@ -1881,13 +1938,13 @@ void procBeam(cpCommand_t *cmd)
 	  appstr( " transported, ", cbuf );
 	  appint( num - total, cbuf );
 	  appstr( " to go.", cbuf );
-	  stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK);
+	  sendFeedback(cbuf);
 	  ototal = total;
 	}
       
       if ( dirup && Planets[pnum].armies <= MIN_BEAM_ARMIES )
 	{
-	  stormsgf(MSG_COMP, snum, lastfew, MSG_FLAGS_FEEDBACK);
+	  sendFeedback(lastfew);
 	  break;
 	}
       
@@ -1903,12 +1960,10 @@ void procBeam(cpCommand_t *cmd)
   if ( conqed )
     {
       sprintf( cbuf, "You have conquered %s.", Planets[pnum].name );
-      stormsgf(MSG_COMP, snum, cbuf, MSG_FLAGS_FEEDBACK);
+      sendFeedback(cbuf);
     }
   else if ( zeroed )
-    stormsgf(MSG_COMP, snum, 
-	     "Sensors show hostile forces eliminated from the planet.",
-	     MSG_FLAGS_FEEDBACK);
+    sendFeedback("Sensors show hostile forces eliminated from the planet.");
   
   return;
   
@@ -1937,11 +1992,9 @@ void procDestruct(cpCommand_t *cmd)
 
   if ( SCLOAKED(snum) )
     {
-      stormsgf(MSG_COMP, snum, 
-	      "The cloaking device is using all available power.",
-               MSG_FLAGS_FEEDBACK);
       sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED,
 	      NULL);
+      sendFeedback("The cloaking device is using all available power.");
       return;
     }
 
@@ -1961,7 +2014,7 @@ void procDestruct(cpCommand_t *cmd)
       if ( Ships[Context.snum].sdfuse < 3 )
 	Context.msgok = FALSE;
 
-      if ( ! stillalive( Context.snum ) )
+      if ( ! clbStillAlive( Context.snum ) )
 	{
 	  /* Died in the process. */
 	  Ships[Context.snum].sdfuse = 0;
@@ -1988,17 +2041,17 @@ void procDestruct(cpCommand_t *cmd)
 		Doomsday->x, Doomsday->y) <= DOOMSDAY_KILL_DIST )
 	{
 	  Doomsday->status = DS_OFF;
-	  stormsg( MSG_DOOM, MSG_ALL, "AIEEEEEEEE!" );
-	  killship( Context.snum, KB_GOTDOOMSDAY );
+	  clbStoreMsg( MSG_DOOM, MSG_ALL, "AIEEEEEEEE!" );
+	  clbKillShip( Context.snum, KB_GOTDOOMSDAY );
 	}
       else
-	if (stillalive(Context.snum))	/* if we're not dead yet... */
-	  killship( Context.snum, KB_SELF );
+	if (clbStillAlive(Context.snum))	/* if we're not dead yet... */
+	  clbKillShip( Context.snum, KB_SELF );
     }
   else
     {
-      if (stillalive(Context.snum))	/* if we're not dead yet... */
-	killship( Context.snum, KB_SELF );
+      if (clbStillAlive(Context.snum))	/* if we're not dead yet... */
+	clbKillShip( Context.snum, KB_SELF );
     }
   
   sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_DONE,
@@ -2034,11 +2087,11 @@ void procAutoPilot(cpCommand_t *cmd)
       return;
     }
 
-  stormsgf(MSG_COMP, snum, "Autopilot activated.", MSG_FLAGS_FEEDBACK);
-  SFSET(snum, SHIP_F_ROBOT);
+ sendFeedback("Autopilot activated.");
+ SFSET(snum, SHIP_F_ROBOT);
 
   gsecs( &laststat );			/* initialize stat timer */
-  while ( stillalive( Context.snum ) )
+  while ( clbStillAlive( Context.snum ) )
     {
       /* Make sure we still control our ship. */
       if ( Ships[snum].pid != Context.pid )
