@@ -4,7 +4,7 @@
  *
  * packet recEvent/pkt generation for the server
  *
- * $Id: serverpkt.c,v 1.3 2003/11/21 02:53:19 jon Exp $
+ * $Id: serverpkt.c,v 1.9 2004/12/26 08:19:31 jon Exp $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -15,6 +15,7 @@
 #include "server.h"
 #include "context.h"
 #include "serverpkt.h"
+#include "conqlb.h"
 
 /* Here, we maintain 2 copies of potential packets, privileged and
    unpriveleged.  We fill the packets, and then return a pointer to a static
@@ -32,12 +33,16 @@ static spShipLoc_t pktShipLoc[MAXSHIPS + 1];
 static spPlanet_t pktPlanet[NUMPLANETS + 1];
 static spPlanetSml_t pktPlanetSml[NUMPLANETS + 1];
 static spPlanetLoc_t pktPlanetLoc[NUMPLANETS + 1];
+static spPlanetLoc2_t pktPlanetLoc2[NUMPLANETS + 1];
 static spUser_t pktUser[MAXUSERS];
 static spTorp_t pktTorp[MAXSHIPS + 1][MAXTORPS];
 static spTorpLoc_t pktTorpLoc[MAXSHIPS + 1][MAXTORPS];
+static spTorpEvent_t pktTorpEvent[MAXSHIPS + 1][MAXTORPS];
 static spTeam_t pktTeam[NUMALLTEAMS];
 static spConqInfo_t pktConqInfo;
 static spHistory_t pktHistory[MAXHISTLOG];
+static spDoomsday_t pktDoomsday;
+static spPlanetInfo_t pktPlanetInfo[NUMPLANETS + 1];
 
 /* recording */
 static spShip_t recShip[MAXSHIPS + 1];
@@ -46,9 +51,13 @@ static spShipLoc_t recShipLoc[MAXSHIPS + 1];
 static spPlanet_t recPlanet[NUMPLANETS + 1];
 static spPlanetSml_t recPlanetSml[NUMPLANETS + 1];
 static spPlanetLoc_t recPlanetLoc[NUMPLANETS + 1];
+static spPlanetLoc2_t recPlanetLoc2[NUMPLANETS + 1];
 static spTorp_t recTorp[MAXSHIPS + 1][MAXTORPS];
 static spTorpLoc_t recTorpLoc[MAXSHIPS + 1][MAXTORPS];
+static spTorpEvent_t recTorpEvent[MAXSHIPS + 1][MAXTORPS];
 static spTeam_t recTeam[NUMALLTEAMS];
+static spDoomsday_t recDoomsday;
+static spPlanetInfo_t recPlanetInfo[NUMPLANETS + 1];
 
 /* memset everything to 0 */
 void spktInit(void)
@@ -68,14 +77,18 @@ void spktInitPkt(void)
   memset((void *)pktPlanet, 0, sizeof(spPlanet_t) * (NUMPLANETS + 1));
   memset((void *)pktPlanetSml, 0, sizeof(spPlanetSml_t) * (NUMPLANETS + 1));
   memset((void *)pktPlanetLoc, 0, sizeof(spPlanetLoc_t) * (NUMPLANETS + 1));
+  memset((void *)pktPlanetLoc2, 0, sizeof(spPlanetLoc2_t) * (NUMPLANETS + 1));
   memset((void *)pktUser, 0, sizeof(spUser_t) * MAXUSERS);
   memset((void *)pktTorp, 0,  sizeof(spTorp_t) * (MAXSHIPS + 1) * MAXTORPS);
   memset((void *)pktTorpLoc, 0,  
          sizeof(spTorpLoc_t) * (MAXSHIPS + 1) * MAXTORPS);
+  memset((void *)pktTorpEvent, 0,  
+         sizeof(spTorpEvent_t) * (MAXSHIPS + 1) * MAXTORPS);
   memset((void *)pktTeam, 0,  sizeof(spTeam_t) * NUMALLTEAMS);
   memset((void *)&pktConqInfo, 0,  sizeof(spConqInfo_t));
   memset((void *)pktHistory, 0,  sizeof(spHistory_t) * MAXHISTLOG);
-
+  memset((void *)&pktDoomsday, 0,  sizeof(spDoomsday_t));
+  memset((void *)pktPlanetInfo, 0, sizeof(spPlanetInfo_t) * (NUMPLANETS + 1));
   return;
 }
 
@@ -88,11 +101,16 @@ void spktInitRec(void)
   memset((void *)recPlanet, 0, sizeof(spPlanet_t) * (NUMPLANETS + 1));
   memset((void *)recPlanetSml, 0, sizeof(spPlanetSml_t) * (NUMPLANETS + 1));
   memset((void *)recPlanetLoc, 0, sizeof(spPlanetLoc_t) * (NUMPLANETS + 1));
+  memset((void *)recPlanetLoc2, 0, sizeof(spPlanetLoc2_t) * (NUMPLANETS + 1));
   memset((void *)recTorp, 0,  
          sizeof(spTorp_t) * (MAXSHIPS + 1) * MAXTORPS);
   memset((void *)recTorpLoc, 0,  
          sizeof(spTorpLoc_t) * (MAXSHIPS + 1) * MAXTORPS);
+  memset((void *)recTorpEvent, 0,  
+         sizeof(spTorpEvent_t) * (MAXSHIPS + 1) * MAXTORPS);
   memset((void *)recTeam, 0,  sizeof(spTeam_t) * NUMALLTEAMS);
+  memset((void *)&recDoomsday, 0, sizeof(spDoomsday_t));
+  memset((void *)recPlanetInfo, 0, sizeof(spPlanetInfo_t) * (NUMPLANETS + 1));
 
   return;
 }
@@ -233,7 +251,8 @@ spShipSml_t *spktShipSml(Unsgn8 snum, int rec)
 
   memset((void *)&sshipsml, 0, sizeof(spShipSml_t));
 
-  sflags = SHIP_F_NONE;		/* can't see anything by default */
+  sflags = SHIP_F_NONE;		/* can't see anything by default.  make sure
+                                   SHIP_F_MAP never sneaks in */
 
   sshipsml.type = SP_SHIPSML;
   sshipsml.snum = snum;
@@ -509,12 +528,15 @@ spPlanetSml_t *spktPlanetSml(Unsgn8 pnum, int rec)
   return NULL;
 }
 
-spPlanetLoc_t *spktPlanetLoc(Unsgn8 pnum, int rec)
+spPlanetLoc_t *spktPlanetLoc(Unsgn8 pnum, int rec, int force)
 {
   int snum = Context.snum;
   int team = Ships[snum].team;
   static spPlanetLoc_t splanloc;
-
+  real dx, dy;
+  static real px[NUMPLANETS] = {}; /* saved x/y */
+  static real py[NUMPLANETS] = {}; 
+  
   memset((void *)&splanloc, 0, sizeof(spPlanetLoc_t));
 
   splanloc.type = SP_PLANETLOC;
@@ -523,10 +545,47 @@ spPlanetLoc_t *spktPlanetLoc(Unsgn8 pnum, int rec)
   /* RESTRICT */
   if (Planets[pnum].scanned[team] || rec)
     splanloc.armies = htons(Planets[pnum].armies);
+
+  dx = (real)fabs(Planets[pnum].x - px[pnum]);
+  dy = (real)fabs(Planets[pnum].y - py[pnum]);
+
+
+  /* we try to be clever here by reducing the pkt count.  If armies are
+     the same, and an average delta of the planet's movement is below
+     an empirically determined value, don't bother sending the packet.
+     
+     The idea is that fast moving planets will be updated more frequently
+     than slower moving ones, hopefully reducing the packet count required
+     for the appearence of smoother movement to the user.
+   */
+  if ((splanloc.armies == pktPlanetLoc[pnum].armies) &&
+      ((dx + dy) / 2.0) < 3.0)
+    {
+#if 0
+      clog("REJECT: %s dx = %f dy = %f [%f]", Planets[pnum].name,
+           dx, dy,
+           ((dx + dy) / 2.0));
+#endif
+      
+      if (!rec && !force)
+        return NULL;
+    }
+
+  if (!rec)
+    {
+      px[pnum] = Planets[pnum].x;
+      py[pnum] = Planets[pnum].y;
+    }
+  
+#if 0
+  clog("%s dx = %f dy = %f [%f]", Planets[pnum].name,
+       dx, dy,
+       ((dx + dy) / 2.0));
+#endif
   
   splanloc.x = (Sgn32)htonl((Sgn32)(Planets[pnum].x * 1000.0));
   splanloc.y = (Sgn32)htonl((Sgn32)(Planets[pnum].y * 1000.0));
-  
+
   if (rec)
     {
       if (memcmp((void *)&splanloc, (void *)&recPlanetLoc[pnum],
@@ -549,6 +608,67 @@ spPlanetLoc_t *spktPlanetLoc(Unsgn8 pnum, int rec)
   return NULL;
 }
 
+spPlanetLoc2_t *spktPlanetLoc2(Unsgn8 pnum, int rec, int force)
+{
+  int snum = Context.snum;
+  int team = Ships[snum].team;
+  static spPlanetLoc2_t splanloc2;
+  Unsgn32 iternow = clbGetMillis(); /* we send the loc2 packets only every 5 secs */
+  const Unsgn32 iterwait = 5000.0; /* ms */
+  static Unsgn32 tstart[NUMPLANETS] = {}; /* saved time deltas */
+  int tooearly = FALSE;
+  
+  /* 
+   * We have to handle the case where a planet has just been freshly
+   * scanned (and therefore a real army count is available).  We want
+   * the client to see the true army count as soon as possible.
+   */
+
+  if (!force && (tstart[pnum] != 0 && ((iternow - tstart[pnum]) < iterwait)))
+    tooearly = TRUE;
+  
+  memset((void *)&splanloc2, 0, sizeof(spPlanetLoc2_t));
+
+  splanloc2.type = SP_PLANETLOC2;
+  splanloc2.pnum = pnum;
+
+  /* RESTRICT */
+  if (Planets[pnum].scanned[team] || rec)
+    splanloc2.armies = htons(Planets[pnum].armies);
+
+  if (splanloc2.armies == pktPlanetLoc2[pnum].armies && tooearly)
+    return NULL;
+
+  tstart[pnum] = iternow; 
+
+  splanloc2.x = (Sgn32)htonl((Sgn32)(Planets[pnum].x * 1000.0));
+  splanloc2.y = (Sgn32)htonl((Sgn32)(Planets[pnum].y * 1000.0));
+  splanloc2.orbang = (Unsgn16)htons((Unsgn16)(Planets[pnum].orbang * 100.0));
+
+  if (rec)
+    {
+      if (memcmp((void *)&splanloc2, (void *)&recPlanetLoc2[pnum],
+                 sizeof(spPlanetLoc2_t)))
+        {
+          recPlanetLoc2[pnum] = splanloc2;
+          return &splanloc2;
+        }
+    }
+  else
+    {
+      if (memcmp((void *)&splanloc2, (void *)&pktPlanetLoc2[pnum],
+                 sizeof(spPlanetLoc2_t)))
+        {
+          pktPlanetLoc2[pnum] = splanloc2;
+          return &splanloc2;
+        }
+    }
+
+  return NULL;
+}
+
+
+
 /* non priv */
 spTorp_t *spktTorp(Unsgn8 tsnum, Unsgn8 tnum, int rec)
 {
@@ -660,6 +780,72 @@ spTorpLoc_t *spktTorpLoc(Unsgn8 tsnum, Unsgn8 tnum, int rec)
   return NULL;
 }
 
+/* PRIV */
+spTorpEvent_t *spktTorpEvent(Unsgn8 tsnum, Unsgn8 tnum, int rec)
+{
+  int i;
+  int snum = Context.snum;
+  int team = Ships[snum].team;
+  static spTorpEvent_t storpev;
+  real x, y, dx, dy;
+
+  memset((void *)&storpev, 0, sizeof(spTorpEvent_t));
+
+  storpev.type = SP_TORPEVENT;
+  storpev.snum = tsnum;
+  storpev.tnum = tnum;
+  storpev.status = (Unsgn8)Ships[tsnum].torps[tnum].status;
+
+  /* RESTRICT */
+  /* we can always see friendly torps.  enemy torps can only be seen if 
+     within ACCINFO_DIST of your ship.  torp war stat only applies to
+     your ship. */
+
+  x = Ships[tsnum].torps[tnum].x;
+  y = Ships[tsnum].torps[tnum].y;
+  dx = Ships[tsnum].torps[tnum].dx;
+  dy = Ships[tsnum].torps[tnum].dy;
+
+  storpev.x = (Sgn32)htonl((Sgn32)(x * 1000.0));
+  storpev.y = (Sgn32)htonl((Sgn32)(y * 1000.0));
+  storpev.dx = (Sgn32)htonl((Sgn32)(dx * 1000.0));
+  storpev.dy = (Sgn32)htonl((Sgn32)(dy * 1000.0));
+
+  if (rec)
+    {
+      for (i=0; i < NUMPLAYERTEAMS; i++)
+        if (Ships[tsnum].torps[tnum].war[i])
+          storpev.war |= (1 << i);
+    }
+  else
+    {
+      /* RESTRICT */
+      /* only send 'war' status as it relates to our team */
+      if (Ships[tsnum].torps[tnum].war[team])
+        storpev.war |= (1 << team);
+    }
+
+  /* we only do these if the torp status changed */
+  if (rec)
+    {
+      if (storpev.status != recTorpEvent[tsnum][tnum].status)
+        {
+          recTorpEvent[tsnum][tnum] = storpev;
+          return &storpev;
+        }
+    }
+  else
+    {
+      if (storpev.status != pktTorpEvent[tsnum][tnum].status)
+        {
+          pktTorpEvent[tsnum][tnum] = storpev;
+          return &storpev;
+        }
+    }
+
+  return NULL;
+}
+
 /* PRIV */
 spTeam_t *spktTeam(Unsgn8 team, int force, int rec)
 {
@@ -761,3 +947,79 @@ spHistory_t *spktHistory(int hnum)
 
   return NULL;
 }
+
+spDoomsday_t *spktDoomsday(int rec)
+{
+  static spDoomsday_t dd;
+
+  memset((void *)&dd, 0, sizeof(spDoomsday_t));
+
+  dd.type = SP_DOOMSDAY;
+  dd.status = (Unsgn8)Doomsday->status;
+  dd.heading = htons((Unsgn16)(Doomsday->heading * 10.0));
+  dd.x = (Sgn32)htonl((Sgn32)(Doomsday->x * 1000.0));
+  dd.y = (Sgn32)htonl((Sgn32)(Doomsday->y * 1000.0));
+
+  if (rec)
+    {
+      if (memcmp((void *)&dd, (void *)&recDoomsday,
+                 sizeof(spDoomsday_t)))
+        {
+          recDoomsday = dd;
+          return &dd;
+        }
+    }
+  else
+    {
+      if (memcmp((void *)&dd, (void *)&pktDoomsday,
+                 sizeof(spDoomsday_t)))
+        {
+          pktDoomsday = dd;
+          return &dd;
+        }
+    }
+
+  return NULL;
+}
+
+spPlanetInfo_t *spktPlanetInfo(Unsgn8 pnum, int rec)
+{
+  static spPlanetInfo_t splaninfo;
+
+  memset((void *)&splaninfo, 0, sizeof(spPlanetInfo_t));
+
+  splaninfo.flags = SPPLANETINFO_FLAGS_FVALID;
+
+  splaninfo.type = SP_PLANETINFO;
+  splaninfo.pnum = pnum;
+
+  if (Planets[pnum].real)
+    splaninfo.flags |= SPPLANETINFO_FLAGS_REAL;
+
+  splaninfo.primary = (Unsgn8)Planets[pnum].primary;
+
+  splaninfo.orbrad = (Unsgn32)htonl((Unsgn32)(Planets[pnum].orbrad * 10.0));
+  splaninfo.orbvel = (Sgn32)htonl((Sgn32)(Planets[pnum].orbvel * 100.0)); 
+
+  if (rec)
+    {
+      if (memcmp((void *)&splaninfo, (void *)&recPlanetInfo[pnum],
+                 sizeof(spPlanetInfo_t)))
+        {
+          recPlanetInfo[pnum] = splaninfo;
+          return &splaninfo;
+        }
+    }
+  else
+    {
+      if (memcmp((void *)&splaninfo, (void *)&pktPlanetInfo[pnum],
+                 sizeof(spPlanetInfo_t)))
+        {
+          pktPlanetInfo[pnum] = splaninfo;
+          return &splaninfo;
+        }
+    }
+
+  return NULL;
+}
+
