@@ -1,7 +1,7 @@
 /* 
  * packet test/generation for the server
  *
- * $Id: serverpkt.h,v 1.2 2003/11/02 20:53:00 jon Exp $
+ * $Id: serverpkt.h,v 1.5 2004/08/09 00:45:37 jon Exp $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -28,14 +28,19 @@ spShipLoc_t *spktShipLoc(Unsgn8 snum, int rec);
 
 spPlanet_t *spktPlanet(Unsgn8 pnum, int rec);
 spPlanetSml_t *spktPlanetSml(Unsgn8 pnum, int rec);
-spPlanetLoc_t *spktPlanetLoc(Unsgn8 pnum, int rec);
+spPlanetLoc_t *spktPlanetLoc(Unsgn8 pnum, int rec, int force);
+spPlanetLoc2_t *spktPlanetLoc2(Unsgn8 pnum, int rec, int force);
 
 spTorp_t *spktTorp(Unsgn8 tsnum, Unsgn8 tnum, int rec);
 spTorpLoc_t *spktTorpLoc(Unsgn8 tsnum, Unsgn8 tnum, int rec);
+spTorpEvent_t *spktTorpEvent(Unsgn8 tsnum, Unsgn8 tnum, int rec);
 
 spTeam_t *spktTeam(Unsgn8 team, int force, int rec);
 spConqInfo_t *spktConqInfo(int force);
 
 spHistory_t *spktHistory(int hnum);
+spDoomsday_t *spktDoomsday(int rec);
+
+spPlanetInfo_t *spktPlanetInfo(Unsgn8 pnum, int rec);
 
 #endif /* _SERVERPKT_H */
